@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef ENTRYDELEGATE_H
@@ -28,9 +28,9 @@ namespace KGantt {
 
 class EntryDelegate : public QItemDelegate {
 public:
-    explicit EntryDelegate( KGantt::ConstraintModel* constraintModel, QObject* parent = nullptr );
+    explicit EntryDelegate( KGantt::ConstraintModel* constraintModel, QObject* parent = 0 );
     
-    bool editorEvent( QEvent* event, QAbstractItemModel* model, const QStyleOptionViewItem& option, const QModelIndex& index ) override;
+    bool editorEvent( QEvent* event, QAbstractItemModel* model, const QStyleOptionViewItem& option, const QModelIndex& index );
     
 private:
     void addConstraint(const QModelIndex & index1, const QModelIndex & index2);
