@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef TIMEAXIS_H
@@ -27,7 +27,7 @@ class TimeAxis : public KChart::CartesianAxis
     Q_OBJECT
 public:
     explicit TimeAxis( KChart::AbstractCartesianDiagram* parent );
-    const QString customizedLabel( const QString& label ) const override;
+    const QString customizedLabel( const QString& label ) const;
 };
 
 
