@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef MAINWINDOW_H
@@ -40,9 +40,9 @@ class MainWindow : public QDialog,
     Q_OBJECT
 
 public:
-    explicit MainWindow( QWidget* parent = nullptr );
+    explicit MainWindow( QWidget* parent = 0 );
 
-private Q_SLOTS:
+private slots:
     void indexClicked( const QModelIndex& index );
 
 private:
