@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef ZOOMWIDGET_H
@@ -31,9 +31,9 @@ public:
 
 protected:
     QPointF findNewZoomCenter( const QPoint & pos );
-    void mousePressEvent( QMouseEvent * e ) override;
-    void wheelEvent( QWheelEvent* e ) override;
-    void keyPressEvent( QKeyEvent* e ) override;
+    void mousePressEvent( QMouseEvent * e );
+    void wheelEvent( QWheelEvent* e );
+    void keyPressEvent( QKeyEvent* e );
 };
 
 
