@@ -14,14 +14,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DIAGRAMTYPEDIALOG_H
 #define DIAGRAMTYPEDIALOG_H
 
 #include <QDialog>
-#include <QHash>
+#include <QtCore/QHash>
 
 class QAbstractItemModel;
 namespace KChart
@@ -35,7 +35,7 @@ class DiagramTypeDialog : public QDialog
 public:
     enum DiagramType{ Bar, LyingBar, Line, Plotter, Pie };
     enum Subtype{ Normal, Percent, Stacked };
-    explicit DiagramTypeDialog( KChart::Chart *chart, QWidget *parent = nullptr );
+    explicit DiagramTypeDialog( KChart::Chart *chart, QWidget *parent = 0 );
     ~DiagramTypeDialog();
 
     void setDefaultModels( QHash< DiagramType, QAbstractItemModel* > models );
