@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTPERCENTBARDIAGRAM_P_H
@@ -30,9 +30,9 @@ namespace KChart {
     public:
         explicit PercentBarDiagram( BarDiagram* );
         virtual ~PercentBarDiagram() {}
-        BarDiagram::BarType type() const override;
-        const QPair<QPointF,  QPointF> calculateDataBoundaries() const override;
-        void paint( PaintContext* ctx ) override;
+        virtual BarDiagram::BarType type() const;
+        virtual const QPair<QPointF,  QPointF> calculateDataBoundaries() const;
+        virtual void paint( PaintContext* ctx );
     };
 
 }
