@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartCartesianCoordinatePlane.h"
@@ -36,7 +36,6 @@
 #include <QtDebug>
 #include <QPainter>
 #include <QTime>
-#include <QElapsedTimer>
 
 
 using namespace KChart;
@@ -86,10 +85,10 @@ void CartesianCoordinatePlane::addDiagram( AbstractDiagram* diagram )
                 "CartesianCoordinatePlane::addDiagram", "Only cartesian "
                 "diagrams can be added to a cartesian coordinate plane!" );
     AbstractCoordinatePlane::addDiagram( diagram );
-    connect( diagram,  SIGNAL(layoutChanged(AbstractDiagram*)),
-             SLOT(slotLayoutChanged(AbstractDiagram*)) );
+    connect( diagram,  SIGNAL( layoutChanged ( AbstractDiagram* ) ),
+             SLOT( slotLayoutChanged( AbstractDiagram* ) ) );
 
-    connect( diagram, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
+    connect( diagram, SIGNAL( propertiesChanged() ), this, SIGNAL( propertiesChanged() ) );
 }
 
 
@@ -126,7 +125,7 @@ void CartesianCoordinatePlane::paint( QPainter* painter )
                 continue;
             }
             bool doDumpPaintTime = AbstractDiagram::Private::get( diags[ i ] )->doDumpPaintTime;
-            QElapsedTimer stopWatch;
+            QTime stopWatch;
             if ( doDumpPaintTime ) {
                 stopWatch.start();
             }
@@ -267,7 +266,7 @@ QRectF CartesianCoordinatePlane::calculateRawDataBoundingRect() const
 
 DataDimensionsList CartesianCoordinatePlane::getDataDimensionsList() const
 {
-    const AbstractCartesianDiagram* dgr = diagrams().isEmpty() ? nullptr :
+    const AbstractCartesianDiagram* dgr = diagrams().isEmpty() ? 0 :
                    qobject_cast< const AbstractCartesianDiagram* >( diagrams().first() );
     if ( dgr && dgr->referenceDiagram() ) {
         dgr = dgr->referenceDiagram();
@@ -279,7 +278,7 @@ DataDimensionsList CartesianCoordinatePlane::getDataDimensionsList() const
     // It does make sense to retrieve the orientation from the first diagram. This is because
     // a coordinate plane can either be for horizontal *or* for vertical diagrams. Both at the
     // same time won't work, and thus the orientation for all diagrams is the same as for the first one.
-    const Qt::Orientation diagramOrientation = barDiagram != nullptr ? barDiagram->orientation() : Qt::Vertical;
+    const Qt::Orientation diagramOrientation = barDiagram != 0 ? barDiagram->orientation() : Qt::Vertical;
     const bool diagramIsVertical = diagramOrientation == Qt::Vertical;
 
     DataDimensionsList l;
@@ -445,7 +444,7 @@ void CartesianCoordinatePlane::handleFixedDataCoordinateSpaceRelation( const QRe
         if ( doneSetZoomCenter( newCenter ) )
             changed = true;
         if ( changed )
-            Q_EMIT propertiesChanged();
+            emit propertiesChanged();
     }
 }
 
@@ -468,7 +467,7 @@ void CartesianCoordinatePlane::setIsometricScaling( bool isOn )
     if ( d->isometricScaling != isOn ) {
         d->isometricScaling = isOn;
         layoutDiagrams();
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -517,7 +516,7 @@ void CartesianCoordinatePlane::setZoomFactors( qreal factorX, qreal factorY )
 {
     if ( doneSetZoomFactorX( factorX ) || doneSetZoomFactorY( factorY ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -525,7 +524,7 @@ void CartesianCoordinatePlane::setZoomFactorX( qreal factor )
 {
     if ( doneSetZoomFactorX( factor ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -533,7 +532,7 @@ void CartesianCoordinatePlane::setZoomFactorY( qreal factor )
 {
     if ( doneSetZoomFactorY( factor ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -541,7 +540,7 @@ void CartesianCoordinatePlane::setZoomCenter( const QPointF& point )
 {
     if ( doneSetZoomCenter( point ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -577,8 +576,8 @@ void CartesianCoordinatePlane::setAxesCalcModes( AxesCalcMode mode )
         d->coordinateTransformation.axesCalcModeX != mode ) {
         d->coordinateTransformation.axesCalcModeY = mode;
         d->coordinateTransformation.axesCalcModeX = mode;
-        Q_EMIT propertiesChanged();
-        Q_EMIT viewportCoordinateSystemChanged();
+        emit propertiesChanged();
+        emit viewportCoordinateSystemChanged();
         Q_FOREACH( AbstractDiagram* diag, diagrams() )
         slotLayoutChanged( diag );
     }
@@ -588,9 +587,9 @@ void CartesianCoordinatePlane::setAxesCalcModeY( AxesCalcMode mode )
 {
     if ( d->coordinateTransformation.axesCalcModeY != mode ) {
         d->coordinateTransformation.axesCalcModeY = mode;
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
         setGridNeedsRecalculate();
-        Q_EMIT viewportCoordinateSystemChanged();
+        emit viewportCoordinateSystemChanged();
     }
 }
 
@@ -598,8 +597,8 @@ void CartesianCoordinatePlane::setAxesCalcModeX( AxesCalcMode mode )
 {
     if ( d->coordinateTransformation.axesCalcModeX != mode ) {
         d->coordinateTransformation.axesCalcModeX = mode;
-        Q_EMIT propertiesChanged();
-        Q_EMIT viewportCoordinateSystemChanged();
+        emit propertiesChanged();
+        emit viewportCoordinateSystemChanged();
     }
 }
 
@@ -621,8 +620,8 @@ void CartesianCoordinatePlane::setHorizontalRange( const QPair< qreal, qreal > &
         d->horizontalMin = range.first;
         d->horizontalMax = range.second;
         layoutDiagrams();
-        Q_EMIT propertiesChanged();
-        Q_EMIT boundariesChanged();
+        emit propertiesChanged();
+        emit boundariesChanged();
     }
 }
 
@@ -633,8 +632,8 @@ void CartesianCoordinatePlane::setVerticalRange( const QPair< qreal, qreal > & r
         d->verticalMin = range.first;
         d->verticalMax = range.second;
         layoutDiagrams();
-        Q_EMIT propertiesChanged();
-        Q_EMIT boundariesChanged();
+        emit propertiesChanged();
+        emit boundariesChanged();
     }
 }
 
@@ -656,7 +655,7 @@ void CartesianCoordinatePlane::adjustRangesToData()
     d->verticalMin = dataBoundingRect.top();
     d->verticalMax = dataBoundingRect.bottom();
     layoutDiagrams();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void CartesianCoordinatePlane::adjustHorizontalRangeToData()
@@ -665,7 +664,7 @@ void CartesianCoordinatePlane::adjustHorizontalRangeToData()
     d->horizontalMin = dataBoundingRect.left();
     d->horizontalMax = dataBoundingRect.right();
     layoutDiagrams();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void CartesianCoordinatePlane::adjustVerticalRangeToData()
@@ -674,7 +673,7 @@ void CartesianCoordinatePlane::adjustVerticalRangeToData()
     d->verticalMin = dataBoundingRect.bottom();
     d->verticalMax = dataBoundingRect.top();
     layoutDiagrams();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void CartesianCoordinatePlane::setAutoAdjustHorizontalRangeToData( unsigned int percentEmpty )
@@ -685,7 +684,7 @@ void CartesianCoordinatePlane::setAutoAdjustHorizontalRangeToData( unsigned int
         d->horizontalMin = 0.0;
         d->horizontalMax = 0.0;
         layoutDiagrams();
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -697,7 +696,7 @@ void CartesianCoordinatePlane::setAutoAdjustVerticalRangeToData( unsigned int pe
         d->verticalMin = 0.0;
         d->verticalMax = 0.0;
         layoutDiagrams();
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -721,7 +720,7 @@ void CartesianCoordinatePlane::setGridAttributes(
         d->gridAttributesVertical = a;
     setHasOwnGridAttributes( orientation, true );
     update();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void CartesianCoordinatePlane::resetGridAttributes( Qt::Orientation orientation )
@@ -748,7 +747,7 @@ void CartesianCoordinatePlane::setHasOwnGridAttributes( Qt::Orientation orientat
         d->hasOwnGridAttributesHorizontal = on;
     else
         d->hasOwnGridAttributesVertical = on;
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::hasOwnGridAttributes( Qt::Orientation orientation ) const
@@ -762,7 +761,7 @@ void CartesianCoordinatePlane::setAutoAdjustGridToZoom( bool autoAdjust )
     if ( d->autoAdjustGridToZoom != autoAdjust ) {
         d->autoAdjustGridToZoom = autoAdjust;
         d->grid->setNeedRecalculate();
-        Q_EMIT propertiesChanged();
+        emit propertiesChanged();
     }
 }
 
@@ -778,15 +777,15 @@ AbstractCoordinatePlane* CartesianCoordinatePlane::sharedAxisMasterPlane( QPaint
 {
     CartesianCoordinatePlane* plane = this;
     AbstractCartesianDiagram* diag = dynamic_cast< AbstractCartesianDiagram* >( plane->diagram() );
-    const CartesianAxis* sharedAxis = nullptr;
-    if ( diag != nullptr )
+    const CartesianAxis* sharedAxis = 0;
+    if ( diag != 0 )
     {
         const CartesianAxisList axes = diag->axes();
         Q_FOREACH( const CartesianAxis* a, axes )
         {
             CartesianCoordinatePlane* p = const_cast< CartesianCoordinatePlane* >(
                                               dynamic_cast< const CartesianCoordinatePlane* >( a->coordinatePlane() ) );
-            if ( p != nullptr && p != this )
+            if ( p != 0 && p != this )
             {
                 plane = p;
                 sharedAxis = a;
@@ -794,7 +793,7 @@ AbstractCoordinatePlane* CartesianCoordinatePlane::sharedAxisMasterPlane( QPaint
         }
     }
 
-    if ( plane == this || painter == nullptr )
+    if ( plane == this || painter == 0 )
         return plane;
 
     const QPointF zero = QPointF( 0, 0 );
@@ -828,7 +827,7 @@ void CartesianCoordinatePlane::setHorizontalRangeReversed( bool reverse )
 
     d->reverseHorizontalPlane = reverse;
     layoutDiagrams();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::isHorizontalRangeReversed() const
@@ -843,7 +842,7 @@ void CartesianCoordinatePlane::setVerticalRangeReversed( bool reverse )
 
     d->reverseVerticalPlane = reverse;
     layoutDiagrams();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::isVerticalRangeReversed() const
