@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartCartesianDiagramDataCompressor_p.h"
@@ -66,8 +66,7 @@ CartesianDiagramDataCompressor::AggregatedDataValueAttributes CartesianDiagramDa
 
     // aggregate attributes from all indices in the same CachePosition as index
     CartesianDiagramDataCompressor::AggregatedDataValueAttributes aggregated;
-    const auto neighborIndexes = mapToModel( position );
-    for ( const QModelIndex& neighborIndex : neighborIndexes ) {
+    Q_FOREACH( const QModelIndex& neighborIndex, mapToModel( position ) ) {
         DataValueAttributes attrs = diagram->dataValueAttributes( neighborIndex );
         // only store visible and unique attributes
         if ( !attrs.isVisible() ) {
@@ -300,61 +299,61 @@ void CartesianDiagramDataCompressor::setModel( QAbstractItemModel* model )
         return;
     }
 
-    if ( m_model != nullptr ) {
-        disconnect( m_model, SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                 this, SLOT(slotModelHeaderDataChanged(Qt::Orientation,int,int)) );
-        disconnect( m_model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                 this, SLOT(slotModelDataChanged(QModelIndex,QModelIndex)) );
-        disconnect( m_model, SIGNAL(layoutChanged()),
-                 this, SLOT(slotModelLayoutChanged()) );
-        disconnect( m_model, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                 this, SLOT(slotRowsAboutToBeInserted(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                 this, SLOT(slotRowsInserted(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                 this, SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                 this, SLOT(slotRowsRemoved(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)),
-                 this, SLOT(slotColumnsAboutToBeInserted(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(columnsInserted(QModelIndex,int,int)),
-                 this, SLOT(slotColumnsInserted(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                 this, SLOT(slotColumnsRemoved(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(columnsAboutToBeRemoved(QModelIndex,int,int)),
-                 this, SLOT(slotColumnsAboutToBeRemoved(QModelIndex,int,int)) );
-        disconnect( m_model, SIGNAL(modelReset()),
-                    this, SLOT(rebuildCache()) );
-        m_model = nullptr;
+    if ( m_model != 0 ) {
+        disconnect( m_model, SIGNAL( headerDataChanged( Qt::Orientation, int, int ) ),
+                 this, SLOT( slotModelHeaderDataChanged( Qt::Orientation, int, int ) ) );
+        disconnect( m_model, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),
+                 this, SLOT( slotModelDataChanged( QModelIndex, QModelIndex ) ) );
+        disconnect( m_model, SIGNAL( layoutChanged() ),
+                 this, SLOT( slotModelLayoutChanged() ) );
+        disconnect( m_model, SIGNAL( rowsAboutToBeInserted( QModelIndex, int, int ) ),
+                 this, SLOT( slotRowsAboutToBeInserted( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( rowsInserted( QModelIndex, int, int ) ),
+                 this, SLOT( slotRowsInserted( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( rowsAboutToBeRemoved( QModelIndex, int, int ) ),
+                 this, SLOT( slotRowsAboutToBeRemoved( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),
+                 this, SLOT( slotRowsRemoved( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( columnsAboutToBeInserted( QModelIndex, int, int ) ),
+                 this, SLOT( slotColumnsAboutToBeInserted( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( columnsInserted( QModelIndex, int, int ) ),
+                 this, SLOT( slotColumnsInserted( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),
+                 this, SLOT( slotColumnsRemoved( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( columnsAboutToBeRemoved( QModelIndex, int, int ) ),
+                 this, SLOT( slotColumnsAboutToBeRemoved( QModelIndex, int, int ) ) );
+        disconnect( m_model, SIGNAL( modelReset() ),
+                    this, SLOT( rebuildCache() ) );
+        m_model = 0;
     }
 
     m_modelCache.setModel( model );
 
-    if ( model != nullptr ) {
+    if ( model != 0 ) {
         m_model = model;
-        connect( m_model, SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                 SLOT(slotModelHeaderDataChanged(Qt::Orientation,int,int)) );
-        connect( m_model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                 SLOT(slotModelDataChanged(QModelIndex,QModelIndex)) );
-        connect( m_model, SIGNAL(layoutChanged()),
-                 SLOT(slotModelLayoutChanged()) );
-        connect( m_model, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                 SLOT(slotRowsAboutToBeInserted(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                 SLOT(slotRowsInserted(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                 SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                 SLOT(slotRowsRemoved(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)),
-                 SLOT(slotColumnsAboutToBeInserted(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(columnsInserted(QModelIndex,int,int)),
-                 SLOT(slotColumnsInserted(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                 SLOT(slotColumnsRemoved(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(columnsAboutToBeRemoved(QModelIndex,int,int)),
-                 SLOT(slotColumnsAboutToBeRemoved(QModelIndex,int,int)) );
-        connect( m_model, SIGNAL(modelReset()), SLOT(rebuildCache()) );
+        connect( m_model, SIGNAL( headerDataChanged( Qt::Orientation, int, int ) ),
+                 SLOT( slotModelHeaderDataChanged( Qt::Orientation, int, int ) ) );
+        connect( m_model, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),
+                 SLOT( slotModelDataChanged( QModelIndex, QModelIndex ) ) );
+        connect( m_model, SIGNAL( layoutChanged() ),
+                 SLOT( slotModelLayoutChanged() ) );
+        connect( m_model, SIGNAL( rowsAboutToBeInserted( QModelIndex, int, int ) ),
+                 SLOT( slotRowsAboutToBeInserted( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( rowsInserted( QModelIndex, int, int ) ),
+                 SLOT( slotRowsInserted( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( rowsAboutToBeRemoved( QModelIndex, int, int ) ),
+                 SLOT( slotRowsAboutToBeRemoved( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),
+                 SLOT( slotRowsRemoved( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( columnsAboutToBeInserted( QModelIndex, int, int ) ),
+                 SLOT( slotColumnsAboutToBeInserted( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( columnsInserted( QModelIndex, int, int ) ),
+                 SLOT( slotColumnsInserted( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),
+                 SLOT( slotColumnsRemoved( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( columnsAboutToBeRemoved( QModelIndex, int, int ) ),
+                 SLOT( slotColumnsAboutToBeRemoved( QModelIndex, int, int ) ) );
+        connect( m_model, SIGNAL( modelReset() ), SLOT( rebuildCache() ) );
     }
     rebuildCache();
     calculateSampleStepWidth();
@@ -432,7 +431,7 @@ const CartesianDiagramDataCompressor::DataPoint& CartesianDiagramDataCompressor:
     if ( ! isCached( position ) ) {
         retrieveModelData( position );
     }
-    return m_data.at( position.column ).at( position.row );
+    return m_data[ position.column ][ position.row ];
 }
 
 QPair< QPointF, QPointF > CartesianDiagramDataCompressor::dataBoundaries() const
@@ -445,7 +444,7 @@ QPair< QPointF, QPointF > CartesianDiagramDataCompressor::dataBoundaries() const
 
     for ( int column = 0; column < colCount; ++column )
     {
-        const DataPointVector& data = m_data.at( column );
+        const DataPointVector& data = m_data[ column ];
         int row = 0;
         for ( DataPointVector::const_iterator it = data.begin(); it != data.end(); ++it, ++row )
         {
@@ -499,7 +498,7 @@ void CartesianDiagramDataCompressor::retrieveModelData( const CachePosition& pos
             }
             result.value = std::numeric_limits< qreal >::quiet_NaN();
             result.key = 0.0;
-            for ( const QModelIndex& index : indexes ) {
+            Q_FOREACH( const QModelIndex& index, indexes ) {
                 const qreal value = m_modelCache.data( index );
                 if ( !ISNAN( value ) ) {
                     result.value = ISNAN( result.value ) ? value : result.value + value;
@@ -511,7 +510,7 @@ void CartesianDiagramDataCompressor::retrieveModelData( const CachePosition& pos
             result.value /= indexes.size();
         }
 
-        for ( const QModelIndex& index : indexes ) {
+        Q_FOREACH( const QModelIndex& index, indexes ) {
             // the DataPoint point is visible if any of the underlying, aggregated points is visible
             if ( m_model->data( index, DataHiddenRole ).value<bool>() == false ) {
                 result.hidden = false;
@@ -544,7 +543,7 @@ CartesianDiagramDataCompressor::CachePosition CartesianDiagramDataCompressor::ma
 {
     Q_ASSERT( m_datasetDimension != 0 );
 
-    if ( m_data.size() == 0 || m_data.at( 0 ).size() == 0 ) {
+    if ( m_data.size() == 0 || m_data[ 0 ].size() == 0 ) {
         return mapToCache( QModelIndex() );
     }
     // assumption: indexes per column == 1
@@ -585,17 +584,17 @@ QModelIndexList CartesianDiagramDataCompressor::mapToModel( const CachePosition&
 
 qreal CartesianDiagramDataCompressor::indexesPerPixel() const
 {
-    if ( !m_model || m_data.size() == 0 || m_data.at( 0 ).size() == 0 )  {
+    if ( !m_model || m_data.size() == 0 || m_data[ 0 ].size() == 0 )  {
         return 0;
     }
-    return qreal( m_model->rowCount( m_rootIndex ) ) / qreal( m_data.at( 0 ).size() );
+    return qreal( m_model->rowCount( m_rootIndex ) ) / qreal( m_data[ 0 ].size() );
 }
 
 bool CartesianDiagramDataCompressor::mapsToModelIndex( const CachePosition& position ) const
 {
-    return m_model && m_data.size() > 0 && m_data.at( 0 ).size() > 0 &&
+    return m_model && m_data.size() > 0 && m_data[ 0 ].size() > 0 &&
            position.column >= 0 && position.column < m_data.size() &&
-           position.row >=0 && position.row < m_data.at( 0 ).size();
+           position.row >=0 && position.row < m_data[ 0 ].size();
 }
 
 void CartesianDiagramDataCompressor::invalidate( const CachePosition& position )
@@ -612,7 +611,7 @@ void CartesianDiagramDataCompressor::invalidate( const CachePosition& position )
 bool CartesianDiagramDataCompressor::isCached( const CachePosition& position ) const
 {
     Q_ASSERT( mapsToModelIndex( position ) );
-    const DataPoint& p = m_data.at( position.column ).at( position.row );
+    const DataPoint& p = m_data[ position.column ][ position.row ];
     return p.index.isValid();
 }
 
