@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartLeveyJenningsDiagram.h"
@@ -77,6 +77,9 @@ LeveyJenningsDiagram::~LeveyJenningsDiagram()
 {
 }
 
+/**
+  * Creates an exact copy of this diagram.
+  */
 LineDiagram * LeveyJenningsDiagram::clone() const
 {
     LeveyJenningsDiagram* newDiagram = new LeveyJenningsDiagram( new Private( *d ) );
@@ -98,6 +101,10 @@ bool LeveyJenningsDiagram::compare( const LeveyJenningsDiagram* other ) const
             ( static_cast<const LineDiagram*>(this)->compare( other ) );
 }
 
+/**
+ * Sets the position of the lot change symbol to \a pos.
+ * Valid values are: Qt::AlignTop (default), Qt::AlignBottom.
+ */
 void LeveyJenningsDiagram::setLotChangedSymbolPosition( Qt::Alignment pos )
 {
     if ( d->lotChangedPosition == pos )
@@ -107,11 +114,18 @@ void LeveyJenningsDiagram::setLotChangedSymbolPosition( Qt::Alignment pos )
     update();
 }
 
+/**
+ * Returns the position of the lot change symbol.
+ */
 Qt::Alignment LeveyJenningsDiagram::lotChangedSymbolPosition() const
 {
     return d->lotChangedPosition;
 }
 
+/**
+ * Sets the position of the fluidics pack changed symbol to \a pos.
+ * Valid values are: Qt::AlignBottom (default), Qt::AlignTop.
+ */
 void LeveyJenningsDiagram::setFluidicsPackChangedSymbolPosition( Qt::Alignment pos )
 {
     if ( d->fluidicsPackChangedPosition == pos )
@@ -121,11 +135,18 @@ void LeveyJenningsDiagram::setFluidicsPackChangedSymbolPosition( Qt::Alignment p
     update();
 }
 
+/**
+ * Returns the position of the fluidics pack changed symbol.
+ */
 Qt::Alignment LeveyJenningsDiagram::fluidicsPackChangedSymbolPosition() const
 {
     return d->fluidicsPackChangedPosition;
 }
 
+/**
+ * Sets the position of the sensor changed symbol to \a pos.
+ * Valid values are: Qt::AlignBottom (default), Qt::AlignTop.
+ */
 void LeveyJenningsDiagram::setSensorChangedSymbolPosition( Qt::Alignment pos )
 {
     if ( d->sensorChangedPosition == pos )
@@ -135,11 +156,17 @@ void LeveyJenningsDiagram::setSensorChangedSymbolPosition( Qt::Alignment pos )
     update();
 }
 
+/**
+ * Returns the position of the sensor changed symbol.
+ */
 Qt::Alignment LeveyJenningsDiagram::sensorChangedSymbolPosition() const
 {
     return d->sensorChangedPosition;
 }
 
+/**
+ * Sets the date/time of all fluidics pack changes to \a changes.
+ */
 void LeveyJenningsDiagram::setFluidicsPackChanges( const QVector< QDateTime >& changes )
 {
     if ( d->fluidicsPackChanges == changes )
@@ -149,11 +176,17 @@ void LeveyJenningsDiagram::setFluidicsPackChanges( const QVector< QDateTime >& c
     update();
 }
 
+/**
+ * Returns the list of all fluidics pack changes.
+ */
 QVector< QDateTime > LeveyJenningsDiagram::fluidicsPackChanges() const
 {
     return d->fluidicsPackChanges;
 }
 
+/**
+ * Sets the date/time of all sensor changes to \a changes.
+ */
 void LeveyJenningsDiagram::setSensorChanges( const QVector< QDateTime >& changes )
 {
     if ( d->sensorChanges == changes )
@@ -163,6 +196,9 @@ void LeveyJenningsDiagram::setSensorChanges( const QVector< QDateTime >& changes
     update();
 }
 
+/**
+ * Sets the pen used for drawing the scan line to \a pen
+ */
 void LeveyJenningsDiagram::setScanLinePen( const QPen& pen )
 {
     if ( d->scanLinePen == pen )
@@ -172,34 +208,49 @@ void LeveyJenningsDiagram::setScanLinePen( const QPen& pen )
     update();
 }
 
+/**
+ * Returns the pen being used for drawing the scan line.
+ */
 QPen LeveyJenningsDiagram::scanLinePen() const
 {
     return d->scanLinePen;
 }
 
+/**
+ * Returns the SVG file name usef for \a symbol
+ */
 QString LeveyJenningsDiagram::symbol( Symbol symbol ) const
 {
     return d->icons[ symbol ];
 }
 
+/**
+ * Sets the symbol being used for \a symbol to a SVG file \a filename.
+ */
 void LeveyJenningsDiagram::setSymbol( Symbol symbol, const QString& filename )
 {
     if ( d->icons[ symbol ] == filename )
         return;
 
     delete d->iconRenderer[ symbol ];
-    d->iconRenderer[ symbol ] = nullptr;
+    d->iconRenderer[ symbol ] = 0;
 
     d->icons[ symbol ] = filename;
 
     update();
 }
 
+/**
+ * Returns the list of all sensor changes.
+ */
 QVector< QDateTime > LeveyJenningsDiagram::sensorChanges() const
 {
     return d->sensorChanges;
 }
 
+/**
+ * Sets the expected mean value over all QC values to \a meanValue.
+ */
 void LeveyJenningsDiagram::setExpectedMeanValue( float meanValue )
 {
     if ( d->expectedMeanValue == meanValue )
@@ -210,11 +261,17 @@ void LeveyJenningsDiagram::setExpectedMeanValue( float meanValue )
     update();
 }
 
+/**
+ * Returns the expected mean values over all QC values.
+ */
 float LeveyJenningsDiagram::expectedMeanValue() const
 {
     return d->expectedMeanValue;
 }
 
+/**
+ * Sets the expected standard deviaction over all QC values to \a sd.
+ */
 void LeveyJenningsDiagram::setExpectedStandardDeviation( float sd )
 {
     if ( d->expectedStandardDeviation == sd )
@@ -225,16 +282,25 @@ void LeveyJenningsDiagram::setExpectedStandardDeviation( float sd )
     update();
 }
 
+/**
+ * Returns the expected standard deviation over all QC values.
+ */
 float LeveyJenningsDiagram::expectedStandardDeviation() const
 {
     return d->expectedStandardDeviation;
 }
 
+/**
+ * Returns the calculated mean values over all QC values.
+ */
 float LeveyJenningsDiagram::calculatedMeanValue() const
 {
     return d->calculatedMeanValue;
 }
 
+/**
+ * Returns the calculated standard deviation over all QC values.
+ */
 float LeveyJenningsDiagram::calculatedStandardDeviation() const
 {
     return d->calculatedStandardDeviation;
@@ -242,40 +308,40 @@ float LeveyJenningsDiagram::calculatedStandardDeviation() const
 
 void LeveyJenningsDiagram::setModel( QAbstractItemModel* model )
 {
-    if ( this->model() != nullptr )
+    if ( this->model() != 0 )
     {
-        disconnect( this->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(columnsInserted(QModelIndex,int,int)),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(modelReset()),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
-        disconnect( this->model(), SIGNAL(layoutChanged()),
-                                   this, SLOT(calculateMeanAndStandardDeviation()) );
+        disconnect( this->model(), SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( modelReset() ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
+        disconnect( this->model(), SIGNAL( layoutChanged() ),
+                                   this, SLOT( calculateMeanAndStandardDeviation() ) );
     }
     LineDiagram::setModel( model );
-    if ( this->model() != nullptr )
+    if ( this->model() != 0 )
     {
-        connect( this->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(columnsInserted(QModelIndex,int,int)),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(columnsRemoved(QModelIndex,int,int)),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(modelReset()),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
-        connect( this->model(), SIGNAL(layoutChanged()),
-                                this, SLOT(calculateMeanAndStandardDeviation()) );
+        connect( this->model(), SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( modelReset() ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
+        connect( this->model(), SIGNAL( layoutChanged() ),
+                                this, SLOT( calculateMeanAndStandardDeviation() ) );
 
         calculateMeanAndStandardDeviation();
     }
@@ -303,7 +369,7 @@ void LeveyJenningsDiagram::calculateMeanAndStandardDeviation() const
 
     qreal sum = 0.0;
     qreal sumSquares = 0.0;
-    for ( qreal value : qAsConst(values) )
+    Q_FOREACH( qreal value, values )
     {
         sum += value;
         sumSquares += value * value;
@@ -349,6 +415,7 @@ static QDateTime ceilHour( const QDateTime& dt )
     return result;
 }
 
+/** \reimpl */
 const QPair<QPointF, QPointF> LeveyJenningsDiagram::calculateDataBoundaries() const
 {
     const qreal yMin = d->expectedMeanValue - 4 * d->expectedStandardDeviation;
@@ -358,8 +425,8 @@ const QPair<QPointF, QPointF> LeveyJenningsDiagram::calculateDataBoundaries() co
 
     // rounded down/up to the prev/next midnight (at least that's the default)
     const QPair< QDateTime, QDateTime > range = timeRange();
-    const unsigned int minTime = range.first.toSecsSinceEpoch();
-    const unsigned int maxTime = range.second.toSecsSinceEpoch();
+    const unsigned int minTime = range.first.toTime_t();
+    const unsigned int maxTime = range.second.toTime_t();
 
     const qreal xMin = minTime / static_cast< qreal >( 24 * 60 * 60 );
     const qreal xMax = maxTime / static_cast< qreal >( 24 * 60 * 60 ) - xMin;
@@ -370,6 +437,9 @@ const QPair<QPointF, QPointF> LeveyJenningsDiagram::calculateDataBoundaries() co
     return QPair< QPointF, QPointF >( bottomLeft, topRight );
 }
 
+/**
+ * Returns the timerange of the diagram's data.
+ */
 QPair< QDateTime, QDateTime > LeveyJenningsDiagram::timeRange() const
 {
     if ( d->timeRange != QPair< QDateTime, QDateTime >() )
@@ -387,7 +457,7 @@ QPair< QDateTime, QDateTime > LeveyJenningsDiagram::timeRange() const
         // round down/up to the prev/next midnight
         const QDate min = floorDay( begin );
         const QDate max = ceilDay( end );
-        return QPair< QDateTime, QDateTime >( QDateTime( min, QTime() ), QDateTime( max, QTime() ) );
+        return QPair< QDateTime, QDateTime >( QDateTime( min ), QDateTime( max ) );
     }
     else if ( begin.secsTo( end ) > 3600 )
     {
@@ -400,6 +470,10 @@ QPair< QDateTime, QDateTime > LeveyJenningsDiagram::timeRange() const
     return QPair< QDateTime, QDateTime >( begin, end );
 }
 
+/**
+ * Sets the \a timeRange visible on the x axis. Set it to QPair< QDateTime, QDateTime >()
+ * to use the default auto calculation.
+ */
 void LeveyJenningsDiagram::setTimeRange( const QPair< QDateTime, QDateTime >& timeRange )
 {
     if ( d->timeRange == timeRange )
@@ -409,25 +483,29 @@ void LeveyJenningsDiagram::setTimeRange( const QPair< QDateTime, QDateTime >& ti
     update();
 }
 
+/**
+ * Draws the fluidics pack and sensor changed symbols.
+ */
 void LeveyJenningsDiagram::drawChanges( PaintContext* ctx )
 {
-    const unsigned int minTime = timeRange().first.toSecsSinceEpoch();
+    const unsigned int minTime = timeRange().first.toTime_t();
 
-    for ( const QDateTime& dt : qAsConst(d->fluidicsPackChanges) )
+    Q_FOREACH( const QDateTime& dt, d->fluidicsPackChanges )
     {
-        const qreal xValue = ( dt.toSecsSinceEpoch() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
+        const qreal xValue = ( dt.toTime_t() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
         const QPointF point( xValue, 0.0 );
         drawFluidicsPackChangedSymbol( ctx, point );
     }
 
-    for ( const QDateTime& dt : qAsConst(d->sensorChanges) )
+    Q_FOREACH( const QDateTime& dt, d->sensorChanges )
     {
-        const qreal xValue = ( dt.toSecsSinceEpoch() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
+        const qreal xValue = ( dt.toTime_t() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
         const QPointF point( xValue, 0.0 );
         drawSensorChangedSymbol( ctx, point );
     }
 }
 
+/** \reimpl */
 void LeveyJenningsDiagram::paint( PaintContext* ctx )
 {
     d->reverseMapper.clear();
@@ -448,7 +526,7 @@ void LeveyJenningsDiagram::paint( PaintContext* ctx )
     const QAbstractItemModel& m = *model();
     const int rowCount = m.rowCount( rootIndex() );
 
-    const unsigned int minTime = timeRange().first.toSecsSinceEpoch();
+    const unsigned int minTime = timeRange().first.toTime_t();
 
     painter->setRenderHint( QPainter::Antialiasing, true );
 
@@ -472,7 +550,7 @@ void LeveyJenningsDiagram::paint( PaintContext* ctx )
         const int lot = m.data( lotIndex ).toInt();
         const bool ok = m.data( okIndex ).toBool();
         const QDateTime time = m.data( timeIndex ).toDateTime();
-        const qreal xValue = ( time.toSecsSinceEpoch() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
+        const qreal xValue = ( time.toTime_t() - minTime ) / static_cast< qreal >( 24 * 60 * 60 );
 
         QVariant vExpectedMean = m.data( expectedMeanIndex );
         const qreal expectedMean = vExpectedMean.toReal();
@@ -550,6 +628,11 @@ void LeveyJenningsDiagram::paint( PaintContext* ctx )
     ctx->setCoordinatePlane( plane );
 }
 
+/**
+ * Draws a data point symbol for the data point at \a pos.
+ * @param ok True, when the data point is ok, false otherwise (different symbol)
+ * @param ctx The PaintContext being used
+ */
 void LeveyJenningsDiagram::drawDataPointSymbol( PaintContext* ctx, const QPointF& pos, bool ok )
 {
     const Symbol type = ok ? OkDataPoint : NotOkDataPoint;
@@ -563,6 +646,11 @@ void LeveyJenningsDiagram::drawDataPointSymbol( PaintContext* ctx, const QPointF
     iconRenderer( type )->render( painter, iconRect() );
 }
 
+/**
+ * Draws a lot changed symbol for the data point at \a pos.
+ * @param ctx The PaintContext being used
+ * \sa lotChangedSymbolPosition
+ */
 void LeveyJenningsDiagram::drawLotChangeSymbol( PaintContext* ctx, const QPointF& pos )
 {
     const QPointF transPos = ctx->coordinatePlane()->translate(
@@ -579,6 +667,11 @@ void LeveyJenningsDiagram::drawLotChangeSymbol( PaintContext* ctx, const QPointF
     iconRenderer( LotChanged )->render( painter, iconRect() );
 }
 
+/**
+ * Draws a sensor changed symbol for the data point at \a pos.
+ * @param ctx The PaintContext being used
+ * \sa sensorChangedSymbolPosition
+ */
 void LeveyJenningsDiagram::drawSensorChangedSymbol( PaintContext* ctx, const QPointF& pos )
 {
     const QPointF transPos = ctx->coordinatePlane()->translate(
@@ -594,6 +687,11 @@ void LeveyJenningsDiagram::drawSensorChangedSymbol( PaintContext* ctx, const QPo
     iconRenderer( SensorChanged )->render( painter, iconRect() );
 }
 
+/**
+ * Draws a fluidics pack changed symbol for the data point at \a pos.
+ * @param ctx The PaintContext being used
+ * \sa fluidicsPackChangedSymbolPosition
+ */
 void LeveyJenningsDiagram::drawFluidicsPackChangedSymbol( PaintContext* ctx, const QPointF& pos )
 {
     const QPointF transPos = ctx->coordinatePlane()->translate(
@@ -609,6 +707,9 @@ void LeveyJenningsDiagram::drawFluidicsPackChangedSymbol( PaintContext* ctx, con
     iconRenderer( FluidicsPackChanged )->render( painter, iconRect() );
 }
 
+/**
+ * Returns the rectangle being used for drawing the icons
+ */
 QRectF LeveyJenningsDiagram::iconRect() const
 {
     const Measure m( 12.5, KChartEnums::MeasureCalculationModeAuto, KChartEnums::MeasureOrientationAuto );
@@ -619,9 +720,12 @@ QRectF LeveyJenningsDiagram::iconRect() const
     return QRectF( -height / 2.0, -height / 2.0, height, height );
 }
 
+/**
+ * Returns the SVG icon renderer for \a symbol
+ */
 QSvgRenderer* LeveyJenningsDiagram::iconRenderer( Symbol symbol )
 {
-    if ( d->iconRenderer[ symbol ] == nullptr )
+    if ( d->iconRenderer[ symbol ] == 0 )
         d->iconRenderer[ symbol ] = new QSvgRenderer( d->icons[ symbol ], this );
 
     return d->iconRenderer[ symbol ];
