@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartChart.h"
@@ -151,7 +151,7 @@ using namespace KChart;
 class MyWidgetItem : public QWidgetItem
 {
 public:
-    explicit MyWidgetItem(QWidget *w, Qt::Alignment alignment = Qt::Alignment())
+    explicit MyWidgetItem(QWidget *w, Qt::Alignment alignment = 0)
         : QWidgetItem( w )
     {
         setAlignment( alignment );
@@ -164,19 +164,19 @@ public:
     // the Legends/Advanced example. It will not work well in various ways - won't get enough space and look
     // very broken, will inhibit resizing the window etc.
 
-    QSize sizeHint() const override
+    QSize sizeHint() const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->sizeHint();
     }
 
-    QSize minimumSize() const override
+    QSize minimumSize() const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->minimumSize();
     }
 
-    QSize maximumSize() const override
+    QSize maximumSize() const
     {
         // Not just passing on w->maximumSize() fixes that the size policy of Legend is disregarded, making
         // Legend take all available space, which makes both the Legend internal layout and the overall
@@ -197,29 +197,29 @@ public:
         return ret;
     }
 
-    Qt::Orientations expandingDirections() const override
+    Qt::Orientations expandingDirections() const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         if ( isEmpty() ) {
-            return Qt::Orientations();
+            return Qt::Orientations(0);
         }
         Qt::Orientations e = w->sizePolicy().expandingDirections();
         return e;
     }
 
-    void setGeometry(const QRect &g) override
+    void setGeometry(const QRect &g)
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         w->setGeometry(g);
     }
 
-    QRect geometry() const override
+    QRect geometry() const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->geometry();
     }
 
-    bool hasHeightForWidth() const override
+    bool hasHeightForWidth() const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         bool ret = !isEmpty() &&
@@ -227,14 +227,14 @@ public:
         return ret;
     }
 
-    int heightForWidth( int width ) const override
+    int heightForWidth( int width ) const
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         int ret = w->heightForWidth( width );
         return ret;
     }
 
-    bool isEmpty() const override {
+    bool isEmpty() const {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         // legend->hide() should indeed hide the legend,
         // but a legend in a chart that hasn't been shown yet isn't hidden
@@ -275,7 +275,7 @@ void Chart::Private::slotUnregisterDestroyedPlane( AbstractCoordinatePlane* plan
     coordinatePlanes.removeAll( plane );
     Q_FOREACH ( AbstractCoordinatePlane* p, coordinatePlanes ) {
         if ( p->referenceCoordinatePlane() == plane) {
-            p->setReferenceCoordinatePlane( nullptr );
+            p->setReferenceCoordinatePlane( 0 );
         }
     }
     plane->layoutPlanes();
@@ -284,27 +284,27 @@ void Chart::Private::slotUnregisterDestroyedPlane( AbstractCoordinatePlane* plan
 Chart::Private::Private( Chart* chart_ )
     : chart( chart_ )
     , useNewLayoutSystem( false )
-    , layout(nullptr)
-    , vLayout(nullptr)
-    , planesLayout(nullptr)
-    , headerLayout(nullptr)
-    , footerLayout(nullptr)
-    , dataAndLegendLayout(nullptr)
-    , leftOuterSpacer(nullptr)
-    , rightOuterSpacer(nullptr)
-    , topOuterSpacer(nullptr)
-    , bottomOuterSpacer(nullptr)
+    , layout( 0 )
+    , vLayout( 0 )
+    , planesLayout( 0 )
+    , headerLayout( 0 )
+    , footerLayout( 0 )
+    , dataAndLegendLayout( 0 )
+    , leftOuterSpacer( 0 )
+    , rightOuterSpacer( 0 )
+    , topOuterSpacer( 0 )
+    , bottomOuterSpacer( 0 )
     , isFloatingLegendsLayoutDirty( true )
     , isPlanesLayoutDirty( true )
-    , globalLeadingLeft(0)
-    , globalLeadingRight(0)
-    , globalLeadingTop(0)
-    , globalLeadingBottom(0)
+    , globalLeadingLeft( 0 )
+    , globalLeadingRight( 0 )
+    , globalLeadingTop( 0 )
+    , globalLeadingBottom( 0 )
 {
     for ( int row = 0; row < 3; ++row ) {
         for ( int column = 0; column < 3; ++column ) {
             for ( int i = 0; i < 2; i++ ) {
-                innerHdFtLayouts[ i ][ row ][ column ] = nullptr;
+                innerHdFtLayouts[ i ][ row ][ column ] = 0;
             }
         }
     }
@@ -465,7 +465,7 @@ static CoordinatePlaneList findSharingAxisDiagrams( AbstractCoordinatePlane* pla
     return result;
 }
 
-/*
+/**
   * this method determines the needed layout of the graph
   * taking care of the sharing problematic
   * its NOT allowed to have a diagram that shares
@@ -638,9 +638,9 @@ QHash<AbstractCoordinatePlane*, PlaneInfo> Chart::Private::buildPlaneLayoutInfos
         }
         // Create a new grid layout for each plane that has no reference.
         p = planeInfos[plane];
-        if ( p.referencePlane == nullptr ) {
+        if ( p.referencePlane == 0 ) {
             p.gridLayout = new QGridLayout();
-            p.gridLayout->setContentsMargins( 0, 0, 0, 0 );
+            p.gridLayout->setMargin( 0 );
             planeInfos[plane] = p;
         }
     }
@@ -655,7 +655,7 @@ void Chart::Private::slotLayoutPlanes()
     if ( planesLayout && dataAndLegendLayout )
         dataAndLegendLayout->removeItem( planesLayout );
 
-    const bool hadPlanesLayout = planesLayout != nullptr;
+    const bool hadPlanesLayout = planesLayout != 0;
     int left, top, right, bottom;
     if ( hadPlanesLayout )
         planesLayout->getContentsMargins(&left, &top, &right, &bottom);
@@ -719,10 +719,10 @@ void Chart::Private::slotLayoutPlanes()
                         {
                             gridPlaneLayout->addItem( curColComponent->diagramPlane, row + planeRowOffset, col + planeColOffset, 2, 2 );
                             curColComponent->diagramPlane->setParentLayout( gridPlaneLayout );
-                            QHBoxLayout *leftLayout = nullptr;
-                            QHBoxLayout *rightLayout = nullptr;
-                            QVBoxLayout *topLayout = nullptr;
-                            QVBoxLayout *bottomLayout = nullptr;
+                            QHBoxLayout *leftLayout = 0;
+                            QHBoxLayout *rightLayout = 0;
+                            QVBoxLayout *topLayout = 0;
+                            QVBoxLayout *bottomLayout = 0;
                             if ( curComponent->sharedSuccesor )
                             {
                                 gridPlaneLayout->addItem( curColComponent->sharedSuccesor->diagramPlane, row + planeRowOffset, col + planeColOffset, 2, 2 );
@@ -831,7 +831,7 @@ void Chart::Private::slotLayoutPlanes()
             planesLayout->setContentsMargins( left, top, right, bottom );
         }
 
-        planesLayout->setContentsMargins( 0, 0, 0, 0 );
+        planesLayout->setMargin( 0 );
         planesLayout->setSpacing( 0 );
         planesLayout->setObjectName( QString::fromLatin1( "planesLayout" ) );
 
@@ -868,7 +868,7 @@ void Chart::Private::slotLayoutPlanes()
              * column of the shared grid. */
             planeLayoutItems << plane;
             plane->setParentLayout( planeLayout );
-            planeLayout->addItem( plane, row, column, 1, 1 );
+            planeLayout->addItem( plane, row, column, 1, 1, 0 );
             //qDebug() << "Chart slotLayoutPlanes() calls planeLayout->addItem("<< row << column << ")";
             planeLayout->setRowStretch( row, 2 );
             planeLayout->setColumnStretch( column, 2 );
@@ -880,7 +880,7 @@ void Chart::Private::slotLayoutPlanes()
                     continue;  // FIXME what about polar ?
                 }
 
-                if ( pi.referencePlane != nullptr )
+                if ( pi.referencePlane != 0 )
                 {
                     pi.topAxesLayout = planeInfos[ pi.referencePlane ].topAxesLayout;
                     pi.bottomAxesLayout = planeInfos[ pi.referencePlane ].bottomAxesLayout;
@@ -889,32 +889,32 @@ void Chart::Private::slotLayoutPlanes()
                 }
 
                 // collect all axes of a kind into sublayouts
-                if ( pi.topAxesLayout == nullptr )
+                if ( pi.topAxesLayout == 0 )
                 {
                     pi.topAxesLayout = new QVBoxLayout;
-                    pi.topAxesLayout->setContentsMargins( 0, 0, 0, 0 );
+                    pi.topAxesLayout->setMargin( 0 );
                     pi.topAxesLayout->setObjectName( QString::fromLatin1( "topAxesLayout" ) );
                 }
-                if ( pi.bottomAxesLayout == nullptr )
+                if ( pi.bottomAxesLayout == 0 )
                 {
                     pi.bottomAxesLayout = new QVBoxLayout;
-                    pi.bottomAxesLayout->setContentsMargins( 0, 0, 0, 0 );
+                    pi.bottomAxesLayout->setMargin( 0 );
                     pi.bottomAxesLayout->setObjectName( QString::fromLatin1( "bottomAxesLayout" ) );
                 }
-                if ( pi.leftAxesLayout == nullptr )
+                if ( pi.leftAxesLayout == 0 )
                 {
                     pi.leftAxesLayout = new QHBoxLayout;
-                    pi.leftAxesLayout->setContentsMargins( 0, 0, 0, 0 );
+                    pi.leftAxesLayout->setMargin( 0 );
                     pi.leftAxesLayout->setObjectName( QString::fromLatin1( "leftAxesLayout" ) );
                 }
-                if ( pi.rightAxesLayout == nullptr )
+                if ( pi.rightAxesLayout == 0 )
                 {
                     pi.rightAxesLayout = new QHBoxLayout;
-                    pi.rightAxesLayout->setContentsMargins( 0, 0, 0, 0 );
+                    pi.rightAxesLayout->setMargin( 0 );
                     pi.rightAxesLayout->setObjectName( QString::fromLatin1( "rightAxesLayout" ) );
                 }
 
-                if ( pi.referencePlane != nullptr )
+                if ( pi.referencePlane != 0 )
                 {
                     planeInfos[ pi.referencePlane ].topAxesLayout = pi.topAxesLayout;
                     planeInfos[ pi.referencePlane ].bottomAxesLayout = pi.bottomAxesLayout;
@@ -1009,7 +1009,7 @@ void Chart::Private::createLayouts()
 {
     // The toplevel layout provides the left and right global margins
     layout = new QHBoxLayout( chart );
-    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->setMargin( 0 );
     layout->setObjectName( QString::fromLatin1( "Chart::Private::layout" ) );
     layout->addSpacing( globalLeadingLeft );
     leftOuterSpacer = layout->itemAt( layout->count() - 1 )->spacerItem();
@@ -1017,7 +1017,7 @@ void Chart::Private::createLayouts()
     // The vLayout provides top and bottom global margins and lays
     // out headers, footers and the diagram area.
     vLayout = new QVBoxLayout();
-    vLayout->setContentsMargins( 0, 0, 0, 0 );
+    vLayout->setMargin( 0 );
     vLayout->setObjectName( QString::fromLatin1( "vLayout" ) );
 
     layout->addLayout( vLayout, 1000 );
@@ -1029,16 +1029,16 @@ void Chart::Private::createLayouts()
     topOuterSpacer = vLayout->itemAt( vLayout->count() - 1 )->spacerItem();
     // 2. the header area
     headerLayout = new QGridLayout();
-    headerLayout->setContentsMargins( 0, 0, 0, 0 );
+    headerLayout->setMargin( 0 );
     vLayout->addLayout( headerLayout );
     // 3. the area containing coordinate planes, axes, and legends
     dataAndLegendLayout = new QGridLayout();
-    dataAndLegendLayout->setContentsMargins( 0, 0, 0, 0 );
+    dataAndLegendLayout->setMargin( 0 );
     dataAndLegendLayout->setObjectName( QString::fromLatin1( "dataAndLegendLayout" ) );
     vLayout->addLayout( dataAndLegendLayout, 1000 );
     // 4. the footer area
     footerLayout = new QGridLayout();
-    footerLayout->setContentsMargins( 0, 0, 0, 0 );
+    footerLayout->setMargin( 0 );
     footerLayout->setObjectName( QString::fromLatin1( "footerLayout" ) );
     vLayout->addLayout( footerLayout );
 
@@ -1051,7 +1051,7 @@ void Chart::Private::createLayouts()
             const Qt::Alignment align = s_gridAlignments[ row ][ column ];
             for ( int headOrFoot = 0; headOrFoot < 2; headOrFoot++ ) {
                 QVBoxLayout* innerLayout = new QVBoxLayout();
-                innerLayout->setContentsMargins( 0, 0, 0, 0 );
+                innerLayout->setMargin( 0 );
                 innerLayout->setAlignment( align );
                 innerHdFtLayouts[ headOrFoot ][ row ][ column ] = innerLayout;
 
@@ -1219,7 +1219,7 @@ AbstractCoordinatePlane* Chart::coordinatePlane()
 {
     if ( d->coordinatePlanes.isEmpty() ) {
         qWarning() << "Chart::coordinatePlane: warning: no coordinate plane defined.";
-        return nullptr;
+        return 0;
     } else {
         return d->coordinatePlanes.first();
     }
@@ -1242,12 +1242,12 @@ void Chart::insertCoordinatePlane( int index, AbstractCoordinatePlane* plane )
         return;
     }
 
-    connect( plane, SIGNAL(destroyedCoordinatePlane(AbstractCoordinatePlane*)),
-             d,   SLOT(slotUnregisterDestroyedPlane(AbstractCoordinatePlane*)) );
-    connect( plane, SIGNAL(needUpdate()),       this,   SLOT(update()) );
-    connect( plane, SIGNAL(needRelayout()),     d,      SLOT(slotResizePlanes()) ) ;
-    connect( plane, SIGNAL(needLayoutPlanes()), d,      SLOT(slotLayoutPlanes()) ) ;
-    connect( plane, SIGNAL(propertiesChanged()),this, SIGNAL(propertiesChanged()) );
+    connect( plane, SIGNAL( destroyedCoordinatePlane( AbstractCoordinatePlane* ) ),
+             d,   SLOT( slotUnregisterDestroyedPlane( AbstractCoordinatePlane* ) ) );
+    connect( plane, SIGNAL( needUpdate() ),       this,   SLOT( update() ) );
+    connect( plane, SIGNAL( needRelayout() ),     d,      SLOT( slotResizePlanes() ) ) ;
+    connect( plane, SIGNAL( needLayoutPlanes() ), d,      SLOT( slotLayoutPlanes() ) ) ;
+    connect( plane, SIGNAL( propertiesChanged() ),this, SIGNAL( propertiesChanged() ) );
     d->coordinatePlanes.insert( index, plane );
     plane->setParent( this );
     d->slotLayoutPlanes();
@@ -1276,16 +1276,16 @@ void Chart::takeCoordinatePlane( AbstractCoordinatePlane* plane )
     const int idx = d->coordinatePlanes.indexOf( plane );
     if ( idx != -1 ) {
         d->coordinatePlanes.takeAt( idx );
-        disconnect( plane, nullptr, d, nullptr );
-        disconnect( plane, nullptr, this, nullptr );
+        disconnect( plane, 0, d, 0 );
+        disconnect( plane, 0, this, 0 );
         plane->removeFromParentLayout();
-        plane->setParent( nullptr );
+        plane->setParent( 0 );
         d->mouseClickedPlanes.removeAll(plane);
     }
     d->slotLayoutPlanes();
-    // Need to Q_EMIT the signal: In case somebody has connected the signal
+    // Need to emit the signal: In case somebody has connected the signal
     // to her own slot for e.g. calling update() on a widget containing the chart.
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void Chart::setGlobalLeading( int left, int top, int right, int bottom )
@@ -1344,39 +1344,65 @@ int Chart::globalLeadingBottom() const
     return d->globalLeadingBottom;
 }
 
-void Chart::paint( QPainter* painter, const QRect& rect )
+void Chart::paint( QPainter* painter, const QRect& target )
 {
-    if ( rect.isEmpty() || !painter ) {
+    if ( target.isEmpty() || !painter ) {
         return;
     }
 
     QPaintDevice* prevDevice = GlobalMeasureScaling::paintDevice();
     GlobalMeasureScaling::setPaintDevice( painter->device() );
-    int prevScaleFactor = PrintingParameters::scaleFactor();
 
-    PrintingParameters::setScaleFactor( qreal( painter->device()->logicalDpiX() ) / qreal( logicalDpiX() ) );
+    // Output on a widget
+    if ( dynamic_cast< QWidget* >( painter->device() ) != 0 ) {
+        GlobalMeasureScaling::setFactors( qreal( target.width() ) / qreal( geometry().size().width() ),
+                                          qreal( target.height() ) / qreal( geometry().size().height() ) );
+    } else {
+        // Output onto a QPixmap
+        PrintingParameters::setScaleFactor( qreal( painter->device()->logicalDpiX() ) / qreal( logicalDpiX() ) );
 
-    const QRect oldGeometry( geometry() );
-    if ( oldGeometry != rect ) {
-        setGeometry( rect );
+        const qreal resX = qreal( logicalDpiX() ) / qreal( painter->device()->logicalDpiX() );
+        const qreal resY = qreal( logicalDpiY() ) / qreal( painter->device()->logicalDpiY() );
+
+        GlobalMeasureScaling::setFactors( qreal( target.width() ) / qreal( geometry().size().width() ) * resX,
+                                          qreal( target.height() ) / qreal( geometry().size().height() ) * resY );
+    }
+
+    const QPoint translation = target.topLeft();
+    painter->translate( translation );
+
+    // the following layout logic has the disadvantage that repeatedly calling this method can
+    // cause a relayout every time, but since this method's main use seems to be printing, the
+    // gratuitous relayouts shouldn't be much of a performance problem.
+    const bool differentSize = target.size() != size();
+    QRect oldGeometry;
+    if ( differentSize ) {
+        oldGeometry = geometry();
+        d->isPlanesLayoutDirty = true;
+        d->isFloatingLegendsLayoutDirty = true;
+        invalidateLayoutTree( d->dataAndLegendLayout );
+        d->dataAndLegendLayout->setGeometry( QRect( QPoint(), target.size() ) );
+    }
+
+    d->overrideSize = target.size();
+    d->paintAll( painter );
+    d->overrideSize = QSize();
+
+    if ( differentSize ) {
+        invalidateLayoutTree( d->dataAndLegendLayout );
+        d->dataAndLegendLayout->setGeometry( oldGeometry );
         d->isPlanesLayoutDirty = true;
         d->isFloatingLegendsLayoutDirty = true;
     }
-    painter->translate( rect.left(), rect.top() );
-    d->paintAll( painter );
 
     // for debugging
     // painter->setPen( QPen( Qt::blue, 8 ) );
-    // painter->drawRect( rect );
+    // painter->drawRect( target );
 
-    painter->translate( -rect.left(), -rect.top() );
-    if ( oldGeometry != rect ) {
-        setGeometry( oldGeometry );
-        d->isPlanesLayoutDirty = true;
-        d->isFloatingLegendsLayoutDirty = true;
-    }
+    painter->translate( -translation.x(), -translation.y() );
 
-    PrintingParameters::setScaleFactor( prevScaleFactor );
+    GlobalMeasureScaling::instance()->resetFactors();
+    PrintingParameters::resetScaleFactor();
     GlobalMeasureScaling::setPaintDevice( prevDevice );
 }
 
@@ -1423,7 +1449,7 @@ void Chart::paintEvent( QPaintEvent* )
 {
     QPainter painter( this );
     d->paintAll( &painter );
-    Q_EMIT finishedDrawing();
+    emit finishedDrawing();
 }
 
 void Chart::addHeaderFooter( HeaderFooter* hf )
@@ -1439,10 +1465,10 @@ void Chart::addHeaderFooter( HeaderFooter* hf )
 
     d->headerFooters.append( hf );
     d->textLayoutItems.append( hf );
-    connect( hf, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
-             d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
-    connect( hf, SIGNAL(positionChanged(HeaderFooter*)),
-             d, SLOT(slotHeaderFooterPositionChanged(HeaderFooter*)) );
+    connect( hf, SIGNAL( destroyedHeaderFooter( HeaderFooter* ) ),
+             d, SLOT( slotUnregisterDestroyedHeaderFooter( HeaderFooter* ) ) );
+    connect( hf, SIGNAL( positionChanged( HeaderFooter* ) ),
+             d, SLOT( slotHeaderFooterPositionChanged( HeaderFooter* ) ) );
 
     // set the text attributes (why?)
 
@@ -1489,12 +1515,12 @@ void Chart::takeHeaderFooter( HeaderFooter* headerFooter )
     if ( idx == -1 ) {
         return;
     }
-    disconnect( headerFooter, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
-                d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
+    disconnect( headerFooter, SIGNAL( destroyedHeaderFooter( HeaderFooter* ) ),
+                d, SLOT( slotUnregisterDestroyedHeaderFooter( HeaderFooter* ) ) );
 
     d->headerFooters.takeAt( idx );
     headerFooter->removeFromParentLayout();
-    headerFooter->setParentLayout( nullptr );
+    headerFooter->setParentLayout( 0 );
     d->textLayoutItems.remove( d->textLayoutItems.indexOf( headerFooter ) );
 
     d->slotResizePlanes();
@@ -1509,7 +1535,7 @@ void Chart::Private::slotHeaderFooterPositionChanged( HeaderFooter* hf )
 HeaderFooter* Chart::headerFooter()
 {
     if ( d->headerFooters.isEmpty() ) {
-        return nullptr;
+        return 0;
     } else {
         return d->headerFooters.first();
     }
@@ -1532,7 +1558,7 @@ void Chart::addLegend( Legend* legend )
 {
     legend->show();
     addLegendInternal( legend, true );
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 void Chart::addLegendInternal( Legend* legend, bool setMeasures )
@@ -1590,7 +1616,7 @@ void Chart::addLegendInternal( Legend* legend, bool setMeasures )
         if ( !alignmentsLayout ) {
             alignmentsLayout = new QGridLayout;
             d->dataAndLegendLayout->addLayout( alignmentsLayout, row, column );
-            alignmentsLayout->setContentsMargins( 0, 0, 0, 0 );
+            alignmentsLayout->setMargin( 0 );
         }
 
         // in case there are several legends in the same edge or corner with the same alignment, they are stacked
@@ -1615,17 +1641,17 @@ void Chart::addLegendInternal( Legend* legend, bool setMeasures )
         if ( !sameAlignmentLayout ) {
             sameAlignmentLayout = new QVBoxLayout;
             alignmentsLayout->addLayout( sameAlignmentLayout, row, column );
-            sameAlignmentLayout->setContentsMargins( 0, 0, 0, 0 );
+            sameAlignmentLayout->setMargin( 0 );
         }
 
         sameAlignmentLayout->addItem( new MyWidgetItem( legend, legend->alignment() ) );
     }
 
-    connect( legend, SIGNAL(destroyedLegend(Legend*)),
-             d, SLOT(slotUnregisterDestroyedLegend(Legend*)) );
-    connect( legend, SIGNAL(positionChanged(AbstractAreaWidget*)),
-             d, SLOT(slotLegendPositionChanged(AbstractAreaWidget*)) );
-    connect( legend, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
+    connect( legend, SIGNAL( destroyedLegend( Legend* ) ),
+             d, SLOT( slotUnregisterDestroyedLegend( Legend* ) ) );
+    connect( legend, SIGNAL( positionChanged( AbstractAreaWidget* ) ),
+             d, SLOT( slotLegendPositionChanged( AbstractAreaWidget* ) ) );
+    connect( legend, SIGNAL( propertiesChanged() ), this, SIGNAL( propertiesChanged() ) );
 
     d->slotResizePlanes();
 }
@@ -1655,18 +1681,18 @@ void Chart::takeLegend( Legend* legend )
     }
 
     d->legends.takeAt( idx );
-    disconnect( legend, nullptr, d, nullptr );
-    disconnect( legend, nullptr, this, nullptr );
+    disconnect( legend, 0, d, 0 );
+    disconnect( legend, 0, this, 0 );
     // the following removes the legend from its layout and destroys its MyWidgetItem (the link to the layout)
-    legend->setParent( nullptr );
+    legend->setParent( 0 );
 
     d->slotResizePlanes();
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 Legend* Chart::legend()
 {
-    return d->legends.isEmpty() ? nullptr : d->legends.first();
+    return d->legends.isEmpty() ? 0 : d->legends.first();
 }
 
 LegendList Chart::legends()
