@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTLAYOUTITEMS_H
@@ -43,16 +43,16 @@ namespace KChart {
     class PaintContext;
 
     /**
-     * Base class for all layout items of KChart
+     * Base class for all layout items of KD Chart
      * \internal
      */
     class KCHART_EXPORT AbstractLayoutItem : public QLayoutItem
     {
     public:
-        AbstractLayoutItem( Qt::Alignment itemAlignment = Qt::Alignment() ) :
+        AbstractLayoutItem( Qt::Alignment itemAlignment = 0 ) :
             QLayoutItem( itemAlignment ),
-            mParent( nullptr ),
-            mParentLayout( nullptr ) {}
+            mParent( 0 ),
+            mParentLayout( 0 ) {}
 
         /**
          * Default impl: just call paint.
@@ -64,25 +64,8 @@ namespace KChart {
 
         virtual void paint( QPainter* ) = 0;
 
-
-        /**
-          * Default impl: Paint the complete item using its layouted position and size.
-          */
         virtual void paintCtx( PaintContext* context );
-
-        /**
-            Inform the item about its widget: This enables the item,
-            to trigger that widget's update, whenever the size of the item's
-            contents has changed.
-
-            Thus, you need to call setParentWidget on every item, that
-            has a non-fixed size.
-          */
         virtual void setParentWidget( QWidget* widget );
-
-        /**
-            Report changed size hint: ask the parent widget to recalculate the layout.
-          */
         virtual void sizeHintChanged() const;
 
         void setParentLayout( QLayout* lay )
@@ -119,7 +102,7 @@ namespace KChart {
                         const TextAttributes& attributes,
                         const QObject* autoReferenceArea,
                         KChartEnums::MeasureOrientation autoReferenceOrientation,
-                        Qt::Alignment alignment = Qt::Alignment() );
+                        Qt::Alignment alignment = 0 );
 
         void setAutoReferenceArea( const QObject* area );
         const QObject* autoReferenceArea() const;
@@ -130,34 +113,23 @@ namespace KChart {
         void setTextAlignment( Qt::Alignment );
         Qt::Alignment textAlignment() const;
 
-        /**
-          \brief Use this to specify the text attributes to be used for this item.
-
-          \sa textAttributes
-        */
         void setTextAttributes( const TextAttributes& a );
-
-        /**
-          Returns the text attributes to be used for this item.
-
-          \sa setTextAttributes
-        */
         TextAttributes textAttributes() const;
 
         /** pure virtual in QLayoutItem */
-        bool isEmpty() const override;
+        virtual bool isEmpty() const;
         /** pure virtual in QLayoutItem */
-        Qt::Orientations expandingDirections() const override;
+        virtual Qt::Orientations expandingDirections() const;
         /** pure virtual in QLayoutItem */
-        QSize maximumSize() const override;
+        virtual QSize maximumSize() const;
         /** pure virtual in QLayoutItem */
-        QSize minimumSize() const override;
+        virtual QSize minimumSize() const;
         /** pure virtual in QLayoutItem */
-        QSize sizeHint() const override;
+        virtual QSize sizeHint() const;
         /** pure virtual in QLayoutItem */
-        void setGeometry( const QRect& r ) override;
+        virtual void setGeometry( const QRect& r );
         /** pure virtual in QLayoutItem */
-        QRect geometry() const override;
+        virtual QRect geometry() const;
 
         virtual int marginWidth() const;
 
@@ -169,7 +141,7 @@ namespace KChart {
         virtual qreal realFontSize() const;
         virtual QFont realFont() const;
 
-        void paint( QPainter* ) override;
+        virtual void paint( QPainter* );
 
         QPolygon boundingPolygon() const;
     private:
@@ -201,7 +173,7 @@ namespace KChart {
                               const TextAttributes& attributes,
                               const QObject* autoReferenceArea,
                               KChartEnums::MeasureOrientation autoReferenceOrientation,
-                              Qt::Alignment alignment = Qt::Alignment() );
+                              Qt::Alignment alignment = 0 );
 
         ~TextBubbleLayoutItem();
 
@@ -215,21 +187,21 @@ namespace KChart {
         TextAttributes textAttributes() const;
 
         /** pure virtual in QLayoutItem */
-        bool isEmpty() const override;
+        virtual bool isEmpty() const;
         /** pure virtual in QLayoutItem */
-        Qt::Orientations expandingDirections() const override;
+        virtual Qt::Orientations expandingDirections() const;
         /** pure virtual in QLayoutItem */
-        QSize maximumSize() const override;
+        virtual QSize maximumSize() const;
         /** pure virtual in QLayoutItem */
-        QSize minimumSize() const override;
+        virtual QSize minimumSize() const;
         /** pure virtual in QLayoutItem */
-        QSize sizeHint() const override;
+        virtual QSize sizeHint() const;
         /** pure virtual in QLayoutItem */
-        void setGeometry( const QRect& r ) override;
+        virtual void setGeometry( const QRect& r );
         /** pure virtual in QLayoutItem */
-        QRect geometry() const override;
+        virtual QRect geometry() const;
 
-        void paint( QPainter* painter ) override;
+        virtual void paint( QPainter* painter );
 
     protected:
         int borderWidth() const;
@@ -249,17 +221,17 @@ namespace KChart {
                               const MarkerAttributes& marker,
                               const QBrush& brush,
                               const QPen& pen,
-                              Qt::Alignment alignment = Qt::Alignment() );
+                              Qt::Alignment alignment = 0 );
 
-            Qt::Orientations expandingDirections() const override;
-            QRect geometry() const override;
-            bool isEmpty() const override;
-            QSize maximumSize() const override;
-            QSize minimumSize() const override;
-            void setGeometry( const QRect& r ) override;
-            QSize sizeHint() const override;
+            virtual Qt::Orientations expandingDirections() const;
+            virtual QRect geometry() const;
+            virtual bool isEmpty() const;
+            virtual QSize maximumSize() const;
+            virtual QSize minimumSize() const;
+            virtual void setGeometry( const QRect& r );
+            virtual QSize sizeHint() const;
 
-            void paint( QPainter* ) override;
+            virtual void paint( QPainter* );
 
             static void paintIntoRect(
                     QPainter* painter,
@@ -288,20 +260,20 @@ namespace KChart {
                             int length,
                             const QPen& pen,
                             Qt::Alignment mLegendLineSymbolAlignment,
-                            Qt::Alignment alignment = Qt::Alignment() );
+                            Qt::Alignment alignment = 0 );
 
-            Qt::Orientations expandingDirections() const override;
-            QRect geometry() const override;
-            bool isEmpty() const override;
-            QSize maximumSize() const override;
-            QSize minimumSize() const override;
-            void setGeometry( const QRect& r ) override;
-            QSize sizeHint() const override;
+            virtual Qt::Orientations expandingDirections() const;
+            virtual QRect geometry() const;
+            virtual bool isEmpty() const;
+            virtual QSize maximumSize() const;
+            virtual QSize minimumSize() const;
+            virtual void setGeometry( const QRect& r );
+            virtual QSize sizeHint() const;
 
             void setLegendLineSymbolAlignment(Qt::Alignment legendLineSymbolAlignment);
             virtual Qt::Alignment legendLineSymbolAlignment() const;
 
-            void paint( QPainter* ) override;
+            virtual void paint( QPainter* );
 
             static void paintIntoRect(
                     QPainter* painter,
@@ -331,17 +303,17 @@ namespace KChart {
                                       const MarkerAttributes& marker,
                                       const QBrush& markerBrush,
                                       const QPen& markerPen,
-                                      Qt::Alignment alignment = Qt::Alignment() );
+                                      Qt::Alignment alignment = 0 );
 
-            Qt::Orientations expandingDirections() const override;
-            QRect geometry() const override;
-            bool isEmpty() const override;
-            QSize maximumSize() const override;
-            QSize minimumSize() const override;
-            void setGeometry( const QRect& r ) override;
-            QSize sizeHint() const override;
+            virtual Qt::Orientations expandingDirections() const;
+            virtual QRect geometry() const;
+            virtual bool isEmpty() const;
+            virtual QSize maximumSize() const;
+            virtual QSize minimumSize() const;
+            virtual void setGeometry( const QRect& r );
+            virtual QSize sizeHint() const;
 
-            void paint( QPainter* ) override;
+            virtual void paint( QPainter* );
 
         private:
             AbstractDiagram* mDiagram;
@@ -364,15 +336,15 @@ namespace KChart {
     public:
         HorizontalLineLayoutItem();
 
-        Qt::Orientations expandingDirections() const override;
-        QRect geometry() const override;
-        bool isEmpty() const override;
-        QSize maximumSize() const override;
-        QSize minimumSize() const override;
-        void setGeometry( const QRect& r ) override;
-        QSize sizeHint() const override;
+        virtual Qt::Orientations expandingDirections() const;
+        virtual QRect geometry() const;
+        virtual bool isEmpty() const;
+        virtual QSize maximumSize() const;
+        virtual QSize minimumSize() const;
+        virtual void setGeometry( const QRect& r );
+        virtual QSize sizeHint() const;
 
-        void paint( QPainter* ) override;
+        virtual void paint( QPainter* );
 
     private:
         QRect mRect;
@@ -387,15 +359,15 @@ namespace KChart {
         public:
             VerticalLineLayoutItem();
 
-            Qt::Orientations expandingDirections() const override;
-            QRect geometry() const override;
-            bool isEmpty() const override;
-            QSize maximumSize() const override;
-            QSize minimumSize() const override;
-            void setGeometry( const QRect& r ) override;
-            QSize sizeHint() const override;
+            virtual Qt::Orientations expandingDirections() const;
+            virtual QRect geometry() const;
+            virtual bool isEmpty() const;
+            virtual QSize maximumSize() const;
+            virtual QSize minimumSize() const;
+            virtual void setGeometry( const QRect& r );
+            virtual QSize sizeHint() const;
 
-            void paint( QPainter* ) override;
+            virtual void paint( QPainter* );
 
         private:
             QRect mRect;
@@ -414,7 +386,7 @@ namespace KChart {
      * in the two reference-layouts can display not only their in-bounds
      * content but also their overlapping content reaching out of their area.
      *
-     * KChart's layouting is applying this schema:
+     * KD Chart's layouting is applying this schema:
 \verbatim
     +------------------+-------------------------+-----------------+
     | +--------------+ | +---------------------+ | +-------------+ |
@@ -464,7 +436,7 @@ namespace KChart {
     Monday  Tuesday  Wednesday Thursday Friday
 \endverbatim
      * The last letters of the word "Friday" would have been
-     * cut off in previous versions of KChart - that is
+     * cut off in previous versions of KD Chart - that is
      * if you did not call KChart::Chart::setGlobalLeading().
      *
      * Now the word will be shown completely because there
@@ -478,15 +450,15 @@ namespace KChart {
                     bool layoutIsAtTopPosition, QHBoxLayout *rightLeftLayout,
                     bool layoutIsAtLeftPosition,  QVBoxLayout *topBottomLayout );
 
-            Qt::Orientations expandingDirections() const override;
-            QRect geometry() const override;
-            bool isEmpty() const override;
-            QSize maximumSize() const override;
-            QSize minimumSize() const override;
-            void setGeometry( const QRect& r ) override;
-            QSize sizeHint() const override;
+            virtual Qt::Orientations expandingDirections() const;
+            virtual QRect geometry() const;
+            virtual bool isEmpty() const;
+            virtual QSize maximumSize() const;
+            virtual QSize minimumSize() const;
+            virtual void setGeometry( const QRect& r );
+            virtual QSize sizeHint() const;
 
-            void paint( QPainter* ) override;
+            virtual void paint( QPainter* );
 
         private:
             QRect mRect;
