@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartLegend.h"
@@ -26,7 +26,6 @@
 #include "KTextDocument.h"
 #include <KChartDiagramObserver.h>
 #include "KChartLayoutItems.h"
-#include "KChartPrintingParameters.h"
 
 #include <QFont>
 #include <QGridLayout>
@@ -43,7 +42,7 @@
 using namespace KChart;
 
 Legend::Private::Private() :
-    referenceArea( nullptr ),
+    referenceArea( 0 ),
     position( Position::East ),
     alignment( Qt::AlignCenter ),
     textAlignment( Qt::AlignCenter ),
@@ -91,7 +90,7 @@ Legend::Legend( AbstractDiagram* diagram, QWidget* parent ) :
 
 Legend::~Legend()
 {
-    Q_EMIT destroyedLegend( this );
+    emit destroyedLegend( this );
 }
 
 void Legend::init()
@@ -99,7 +98,7 @@ void Legend::init()
     setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
 
     d->layout = new QGridLayout( this );
-    d->layout->setContentsMargins( 2, 2, 2, 2 );
+    d->layout->setMargin( 2 );
     d->layout->setSpacing( d->spacing );
 
     const Measure normalFontSizeTitle( 12, KChartEnums::MeasureCalculationModeAbsolute );
@@ -190,9 +189,12 @@ Legend::LegendStyle Legend::legendStyle() const
     return d->legendStyle;
 }
 
+/**
+  * Creates an exact copy of this legend.
+  */
 Legend* Legend::clone() const
 {
-    Legend* legend = new Legend( new Private( *d ), nullptr );
+    Legend* legend = new Legend( new Private( *d ), 0 );
     legend->setTextAttributes( textAttributes() );
     legend->setTitleTextAttributes( titleTextAttributes() );
     legend->setFrameAttributes( frameAttributes() );
@@ -255,30 +257,6 @@ void Legend::paint( QPainter* painter )
 #endif
 }
 
-void Legend::paint( QPainter *painter, const QRect& rect )
-{
-    if ( rect.isEmpty() ) {
-        return;
-    }
-    // set up the contents of the widget so we get a useful geometry
-    QPaintDevice* prevDevice = GlobalMeasureScaling::paintDevice();
-    GlobalMeasureScaling::setPaintDevice( painter->device() );
-
-    const QRect oldGeometry(geometry() );
-    const QRect newGeo( QPoint(0,0), rect.size() );
-    if (oldGeometry != newGeo) {
-        setGeometry(newGeo);
-        needSizeHint();
-    }
-    painter->translate( rect.left(), rect.top() );
-    paintAll( *painter );
-    painter->translate( -rect.left(), -rect.top() );
-
-    if (oldGeometry != newGeo) {
-        setGeometry(oldGeometry);
-    }
-    GlobalMeasureScaling::setPaintDevice( prevDevice );
-}
 
 uint Legend::datasetCount() const
 {
@@ -310,7 +288,7 @@ const QWidget* Legend::referenceArea() const
 AbstractDiagram* Legend::diagram() const
 {
     if ( d->observers.isEmpty() ) {
-        return nullptr;
+        return 0;
     }
     return d->observers.first()->diagram();
 }
@@ -345,14 +323,14 @@ void Legend::addDiagram( AbstractDiagram* newDiagram )
         } else {
             d->observers.append( observer );
         }
-        connect( observer, SIGNAL(diagramAboutToBeDestroyed(AbstractDiagram*)),
-                 SLOT(resetDiagram(AbstractDiagram*)));
-        connect( observer, SIGNAL(diagramDataChanged(AbstractDiagram*)),
-                 SLOT(setNeedRebuild()));
-        connect( observer, SIGNAL(diagramDataHidden(AbstractDiagram*)),
-                 SLOT(setNeedRebuild()));
-        connect( observer, SIGNAL(diagramAttributesChanged(AbstractDiagram*)),
-                 SLOT(setNeedRebuild()));
+        connect( observer, SIGNAL( diagramAboutToBeDestroyed(AbstractDiagram*) ),
+                 SLOT( resetDiagram(AbstractDiagram*) ));
+        connect( observer, SIGNAL( diagramDataChanged(AbstractDiagram*) ),
+                 SLOT( setNeedRebuild() ));
+        connect( observer, SIGNAL( diagramDataHidden(AbstractDiagram*) ),
+                 SLOT( setNeedRebuild() ));
+        connect( observer, SIGNAL( diagramAttributesChanged(AbstractDiagram*) ),
+                 SLOT( setNeedRebuild() ));
         setNeedRebuild();
     }
 }
@@ -469,8 +447,8 @@ void Legend::setPosition( Position position )
 
 void Legend::emitPositionChanged()
 {
-    Q_EMIT positionChanged( this );
-    Q_EMIT propertiesChanged();
+    emit positionChanged( this );
+    emit propertiesChanged();
 }
 
 
@@ -592,6 +570,11 @@ bool Legend::useAutomaticMarkerSize() const
     return d->useAutomaticMarkerSize;
 }
 
+/**
+    \brief Removes all legend texts that might have been set by setText.
+
+    This resets the Legend to default behaviour: Texts are created automatically.
+*/
 void Legend::resetTexts()
 {
     if ( !d->texts.count() ) {
@@ -897,10 +880,10 @@ QSizeF Legend::Private::maxMarkerSize( Legend *q, qreal fontHeight ) const
 }
 
 HDatasetItem::HDatasetItem()
-   : markerLine(nullptr),
-     label(nullptr),
-     separatorLine(nullptr),
-     spacer(nullptr)
+   : markerLine(0),
+     label(0),
+     separatorLine(0),
+     spacer(0)
 {}
 
 static void updateToplevelLayout(QWidget *w)
@@ -985,16 +968,14 @@ void Legend::buildLegend()
             const QPen pn = pen( dataset );
             const Qt::PenStyle ps = pn.style();
             if ( ps != Qt::NoPen ) {
-                maxLineLength = qMin( pn.width() * 18, maxLineLength );
+                maxLineLength = qMax( pn.width() * 18, maxLineLength );
                 if ( ps != Qt::SolidLine ) {
                     hasComplexPenStyle = true;
                 }
             }
         }
-        if ( legendStyle() != LinesOnly ) {
-            if ( hasComplexPenStyle )
-              maxLineLength += lineLengthLeftOfMarker;
-            maxLineLength += int( maxMarkerSize.width() );
+        if ( hasComplexPenStyle && legendStyle() != LinesOnly ) {
+            maxLineLength += lineLengthLeftOfMarker + int( maxMarkerSize.width() );
         }
     }
 
@@ -1041,6 +1022,7 @@ void Legend::buildLegend()
         }
 
         // (actual) vertical layout here
+
         if ( dsItem.markerLine ) {
             d->layout->addItem( dsItem.markerLine, vLayoutRow, 1, 1, 1, Qt::AlignCenter );
             d->paintItems << dsItem.markerLine;
@@ -1069,7 +1051,7 @@ void Legend::buildLegend()
 
     updateToplevelLayout( this );
 
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 #ifdef DEBUG_LEGEND_PAINT
     qDebug() << "leaving Legend::buildLegend()";
 #endif
@@ -1117,19 +1099,11 @@ void Legend::Private::flowHDatasetItems( Legend *q )
     const int separatorLineWidth = 3; // hardcoded in VerticalLineLayoutItem::sizeHint()
 
     const int allowedWidth = q->areaGeometry().width();
+
     QHBoxLayout *currentLine = new QHBoxLayout;
-    int columnSpan = 5;
-    int mainLayoutColumn = 0;
-    int row = 0;
-    if ( !titleText.isEmpty() && titleTextAttributes.isVisible() ) {
-        ++row;
-        if (q->showLines()){
-            ++row;
-        }
-    }
-    layout->addItem( currentLine, row, mainLayoutColumn,
-                     /*rowSpan*/1 , columnSpan, Qt::AlignLeft | Qt::AlignVCenter );
-    mainLayoutColumn += columnSpan;
+    int mainLayoutRow = 1;
+    layout->addItem( currentLine, mainLayoutRow++, /*column*/0,
+                     /*rowSpan*/1 , /*columnSpan*/5, Qt::AlignLeft | Qt::AlignVCenter );
 
     for ( int dataset = 0; dataset < hLayoutDatasets.size(); dataset++ ) {
         HDatasetItem *hdsItem = &hLayoutDatasets[ dataset ];
@@ -1143,15 +1117,14 @@ void Legend::Private::flowHDatasetItems( Legend *q )
             if ( currentLine->sizeHint().width() + separatorWidth + payloadWidth > allowedWidth ) {
                 // too wide, "line break"
 #ifdef DEBUG_LEGEND_PAINT
-                qDebug() << Q_FUNC_INFO << "break" << mainLayoutColumn
+                qDebug() << Q_FUNC_INFO << "break" << mainLayoutRow
                          << currentLine->sizeHint().width()
                          << currentLine->sizeHint().width() + separatorWidth + payloadWidth
                          << allowedWidth;
 #endif
                 currentLine = new QHBoxLayout;
-                layout->addItem( currentLine, row, mainLayoutColumn,
-                                 /*rowSpan*/1 , columnSpan, Qt::AlignLeft | Qt::AlignVCenter );
-                mainLayoutColumn += columnSpan;
+                layout->addItem( currentLine, mainLayoutRow++, /*column*/0,
+                                 /*rowSpan*/1 , /*columnSpan*/5, Qt::AlignLeft | Qt::AlignVCenter );
             } else {
                 // > 1 dataset item in line, put spacing and maybe a separator between them
                 if ( !hdsItem->spacer ) {
@@ -1173,11 +1146,11 @@ void Legend::Private::flowHDatasetItems( Legend *q )
         // those have no parents in the current layout, so they wouldn't get cleaned up otherwise
         if ( !spacerUsed ) {
             delete hdsItem->spacer;
-            hdsItem->spacer = nullptr;
+            hdsItem->spacer = 0;
         }
         if ( !separatorUsed ) {
             delete hdsItem->separatorLine;
-            hdsItem->separatorLine = nullptr;
+            hdsItem->separatorLine = 0;
         }
 
         currentLine->addItem( hdsItem->markerLine );
