@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartRingDiagram.h"
@@ -57,6 +57,9 @@ void RingDiagram::init()
 {
 }
 
+/**
+  * Creates an exact copy of this diagram.
+  */
 RingDiagram * RingDiagram::clone() const
 {
     return new RingDiagram( new Private( *d ) );
@@ -182,7 +185,7 @@ void RingDiagram::paint( PaintContext* ctx )
         if ( !d->expandWhenExploded ) {
             maxOffsetInThisRow -= qreal( i );
         }
-        totalOffset += qMax<qreal>( maxOffsetInThisRow, 0.0 );
+        totalOffset += qMax( maxOffsetInThisRow, 0.0 );
         // FIXME: What if explode factor of inner ring is > 1.0 ?
         //if ( !d->expandWhenExploded )
         //      break;
@@ -240,6 +243,11 @@ void RingDiagram::paint( PaintContext* ctx )
 #define trunc(x) ((int)(x))
 #endif
 
+/**
+  \param painter the QPainter to draw in
+  \param dataset the dataset to draw the slice for
+  \param slice the slice to draw
+  */
 void RingDiagram::drawOneSlice( QPainter* painter, uint dataset, uint slice, qreal granularity )
 {
     // Is there anything to draw at all?
@@ -254,6 +262,13 @@ void RingDiagram::resize( const QSizeF& size)
     AbstractPieDiagram ::resize( size );
 }
 
+/**
+  Internal method that draws the top surface of one of the slices in a ring chart.
+
+  \param painter the QPainter to draw in
+  \param dataset the dataset to draw the slice for
+  \param slice the slice to draw
+  */
 void RingDiagram::drawPieSurface( QPainter* painter, uint dataset, uint slice, qreal granularity )
 {
     // Is there anything to draw at all?
@@ -400,6 +415,10 @@ void RingDiagram::drawPieSurface( QPainter* painter, uint dataset, uint slice, q
 }
 
 
+/**
+  * Auxiliary method returning a point to a given boundary
+  * rectangle of the enclosed ellipse and an angle.
+  */
 QPointF RingDiagram::pointOnEllipse( const QRectF& rect, int dataset, int slice, bool outer, qreal angle,
                                      qreal totalGapFactor, qreal totalExplodeFactor )
 {
