@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "kganttgraphicsitem.h"
@@ -35,13 +35,15 @@
 #include <QPainter>
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
+#include <QItemSelectionModel>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsLineItem>
-#include <QApplication>
 
 #include <QDebug>
 
-
+/*!\class KGantt::GraphicsItem
+ * \internal
+ */
 
 using namespace KGantt;
 
@@ -89,7 +91,7 @@ void GraphicsItem::init()
     setAcceptHoverEvents( true );
     setHandlesChildEvents( true );
     setZValue( 100. );
-    m_dragline = nullptr;
+    m_dragline = 0;
 }
 
 int GraphicsItem::type() const
@@ -105,7 +107,6 @@ StyleOptionGanttItem GraphicsItem::getStyleOption() const
         //qDebug()<<"GraphicsItem::getStyleOption: Invalid index";
         return opt;
     }
-    opt.palette = QApplication::palette();
     opt.itemRect = rect();
     opt.boundingRect = boundingRect();
     QVariant tp = m_index.model()->data( m_index, TextPositionRole );
@@ -132,7 +133,7 @@ StyleOptionGanttItem GraphicsItem::getStyleOption() const
         case StyleOptionGanttItem::Center: opt.displayAlignment = Qt::AlignCenter; break;
         }
     }
-    opt.grid = const_cast<AbstractGrid*>(scene()->getGrid());
+    opt.grid = scene()->grid();
     opt.text = m_index.model()->data( m_index, Qt::DisplayRole ).toString();
     if ( isEnabled() ) opt.state  |= QStyle::State_Enabled;
     if ( isSelected() ) opt.state |= QStyle::State_Selected;
@@ -180,11 +181,6 @@ void GraphicsItem::paint( QPainter* painter, const QStyleOptionGraphicsItem* opt
         StyleOptionGanttItem opt = getStyleOption();
         *static_cast<QStyleOption*>(&opt) = *static_cast<const QStyleOption*>( option );
         //opt.fontMetrics = painter->fontMetrics();
-        if (widget) {
-            opt.palette = widget->palette();
-        } else {
-            opt.palette = QApplication::palette();
-        }
         scene()->itemDelegate()->paintGanttItem( painter, opt, index() );
     }
 }
@@ -292,7 +288,7 @@ void GraphicsItem::updateItem( const Span& rowGeometry, const QPersistentModelIn
         return;
     }
 
-    const Span s = scene()->getGrid()->mapToChart( static_cast<const QModelIndex&>(idx) );
+    const Span s = scene()->grid()->mapToChart( static_cast<const QModelIndex&>(idx) );
     setPos( QPointF( s.start(), rowGeometry.start() ) );
     setRect( QRectF( 0., 0., s.length(), rowGeometry.length() ) );
     setIndex( idx );
@@ -332,7 +328,13 @@ QVariant GraphicsItem::itemChange( GraphicsItemChange change, const QVariant& va
     } else if ( change==QGraphicsItem::ItemSelectedChange ) {
         if ( index().isValid() && !( index().model()->flags( index() ) & Qt::ItemIsSelectable ) ) {
             // Reject selection attempt
-            return QVariant::fromValue( false );
+            return qVariantFromValue( false );
+        }
+
+        if ( value.toBool() ) {
+            scene()->selectionModel()->select( index(), QItemSelectionModel::Select );
+        } else {
+            scene()->selectionModel()->select( index(), QItemSelectionModel::Deselect );
         }
     }
 
@@ -342,6 +344,7 @@ QVariant GraphicsItem::itemChange( GraphicsItemChange change, const QVariant& va
 void GraphicsItem::focusInEvent( QFocusEvent* event )
 {
     Q_UNUSED( event );
+    scene()->selectionModel()->select( index(), QItemSelectionModel::SelectCurrent );
 }
 
 void GraphicsItem::updateModel()
@@ -366,7 +369,7 @@ void GraphicsItem::updateModel()
                  it2 != m_endConstraints.end() ;
                  ++it2 )
                 constraints.push_back((*it2)->proxyConstraint());
-            if ( scene()->getGrid()->mapFromChart( Span( scenePos().x(), rect().width() ),
+            if ( scene()->grid()->mapFromChart( Span( scenePos().x(), rect().width() ),
                                                 index(),
                                                 constraints ) ) {
                 scene()->updateRow( index().parent() );
@@ -426,16 +429,13 @@ void GraphicsItem::mousePressEvent( QGraphicsSceneMouseEvent* event )
         m_istate = istate;
         m_presspos = event->pos();
         m_pressscenepos = event->scenePos();
-
-        scene()->itemPressed( index(), event );
+        scene()->itemPressed( index() );
 
         switch ( m_istate ) {
         case ItemDelegate::State_ExtendLeft:
         case ItemDelegate::State_ExtendRight:
         default: /* State_Move */
-            if (!(flags() & ItemIsMovable)) {
-                event->ignore();
-            }
+            BASE::mousePressEvent( event );
             break;
         }
     } else {
@@ -449,7 +449,7 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
     if ( !m_presspos.isNull() ) {
         scene()->itemClicked( index() );
     }
-    delete m_dragline; m_dragline = nullptr;
+    delete m_dragline; m_dragline = 0;
     if ( scene()->dragSource() ) {
         // Create a new constraint
         GraphicsItem* other = qgraphicsitem_cast<GraphicsItem*>( scene()->itemAt( event->scenePos(), QTransform() ) );
@@ -481,7 +481,7 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
             }
         }
 
-        scene()->setDragSource( nullptr );
+        scene()->setDragSource( 0 );
         //scene()->update();
     } else {
         if ( isEditable() ) {
@@ -500,6 +500,7 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
     }
 
     m_presspos = QPointF();
+    BASE::mouseReleaseEvent( event );
 }
 
 void GraphicsItem::mouseDoubleClickEvent( QGraphicsSceneMouseEvent* event )
@@ -565,6 +566,7 @@ void GraphicsItem::mouseMoveEvent( QGraphicsSceneMouseEvent* event )
             break;
         }
 
+        scene()->selectionModel()->setCurrentIndex( index(), QItemSelectionModel::Current );
         updateItemFromMouse(event->scenePos());
         //BASE::mouseMoveEvent(event);
         break;
