@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "kganttgraphicsview.h"
@@ -22,7 +22,6 @@
 #include "kganttabstractrowcontroller.h"
 #include "kganttgraphicsitem.h"
 #include "kganttconstraintmodel.h"
-#include "kganttdatetimetimelinedialog.h"
 
 #include <QMenu>
 #include <QPainter>
@@ -31,9 +30,6 @@
 #include <QScrollBar>
 #include <QAbstractProxyModel>
 #include <QPrinter>
-#include <QItemSelectionModel>
-#include <QGraphicsSceneMouseEvent>
-#include <QGuiApplication>
 
 #include <cassert>
 
@@ -41,17 +37,16 @@
 #include "../evaldialog/evaldialog.h"
 #endif
 
-/*\class KGantt::HeaderWidget
+/*!\class KGantt::HeaderWidget
  * \internal
  */
 
 using namespace KGantt;
 
 HeaderWidget::HeaderWidget( GraphicsView* parent )
-    : QWidget( parent ), m_offset( 0. ), m_headerType( DateTimeGrid::NoHeader )
+    : QWidget( parent ), m_offset( 0. )
 {
     assert( parent ); // Parent must be set
-    setMouseTracking(true);
 }
 
 HeaderWidget::~HeaderWidget()
@@ -85,113 +80,19 @@ bool HeaderWidget::event( QEvent* event )
     return QWidget::event( event );
 }
 
-void HeaderWidget::mousePressEvent(QMouseEvent *event)
-{
-    DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    int mousePosX = event->x();
-    m_headerType = grid->sectionHandleAtPos( view()->mapToScene( event->x(), 0 ).x(), event->pos().y(), geometry() );
-    if (m_headerType != DateTimeGrid::NoHeader) {
-        bool hasCursor = testAttribute(Qt::WA_SetCursor);
-        if (!hasCursor) {
-            setCursor(QCursor(Qt::SplitHCursor));
-        }
-        m_mousePosX = mousePosX;
-        event->accept();
-        return;
-    }
-    QWidget::mousePressEvent( event );
-}
-
-void HeaderWidget::mouseReleaseEvent(QMouseEvent *event)
-{
-    if ( m_headerType > 0 ) {
-        DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-        int mousePosX = view()->mapToScene( event->x(), 0 ).x();
-        if ( grid->sectionHandleAtPos( mousePosX, event->pos().y(), geometry() ) == DateTimeGrid::NoHeader ) {
-            bool hasCursor = testAttribute(Qt::WA_SetCursor);
-            if (hasCursor) {
-                unsetCursor();
-            }
-        }
-        m_headerType = DateTimeGrid::NoHeader;
-        m_mousePosX = event->x();
-        QGuiApplication::restoreOverrideCursor();
-    }
-    QWidget::mouseReleaseEvent(event);
-}
-
-void HeaderWidget::mouseMoveEvent(QMouseEvent *event)
-{
-    DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    int mousePosX = event->x();
-    qreal gridX = view()->mapToScene( event->x(), 0.0 ).x();
-    switch ( m_headerType ) {
-        case DateTimeGrid::UpperHeader:
-        {
-            if ( mousePosX > m_mousePosX )  {
-                grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 1.05 ) );
-            } else {
-                grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() / 1.05 ) );
-            }
-            m_mousePosX = mousePosX;
-            event->accept();
-            return;
-        }
-        case DateTimeGrid::LowerHeader:
-        {
-            if ( mousePosX > m_mousePosX )  {
-                grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 1.01 ) );
-            } else {
-                grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() / 1.01 ) );
-            }
-            m_mousePosX = mousePosX;
-            event->accept();
-            return;
-        }
-        default: {
-            bool hasCursor = testAttribute(Qt::WA_SetCursor);
-            DateTimeGrid::HeaderType type = grid->sectionHandleAtPos( gridX, event->pos().y(), geometry());
-            if (type != DateTimeGrid::NoHeader) {
-                if (!hasCursor) {
-                    setCursor(QCursor(Qt::SplitHCursor));
-                }
-                event->accept();
-                return;
-            }
-            if (hasCursor) {
-                unsetCursor();
-            }
-            break;
-        }
-    }
-    QWidget::mouseMoveEvent(event);
-}
-
-void HeaderWidget::wheelEvent( QWheelEvent *event )
-{
-    DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    if ( event->angleDelta().y() > 0 ) {
-        grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 1.1 ) );
-    } else {
-        grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() / 1.1 ) );
-    }
-    event->accept();
-}
-
 void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
 {
     QMenu contextMenu;
 
     DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    QAction* actionScaleAuto = nullptr;
-    QAction* actionScaleMonth = nullptr;
-    QAction* actionScaleWeek = nullptr;
-    QAction* actionScaleDay = nullptr;
-    QAction* actionScaleHour = nullptr;
-    QAction* actionZoomIn = nullptr;
-    QAction* actionZoomOut = nullptr;
-    QAction* actionTimeline = nullptr;
-    if ( grid != nullptr )
+    QAction* actionScaleAuto = 0;
+    QAction* actionScaleMonth = 0;
+    QAction* actionScaleWeek = 0;
+    QAction* actionScaleDay = 0;
+    QAction* actionScaleHour = 0;
+    QAction* actionZoomIn = 0;
+    QAction* actionZoomOut = 0;
+    if ( grid != 0 )
     {
         QMenu* menuScale = new QMenu( tr( "Scale", "@title:menu" ), &contextMenu );
         QActionGroup* scaleGroup = new QActionGroup( &contextMenu );
@@ -236,10 +137,6 @@ void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
         contextMenu.addAction( actionZoomIn );
         actionZoomOut = new QAction( tr( "Zoom Out", "@action:inmenu" ), &contextMenu );
         contextMenu.addAction( actionZoomOut );
-
-        contextMenu.addSeparator();
-        actionTimeline = new QAction( tr( "Timeline...", "@action:inmenu" ), &contextMenu );
-        contextMenu.addAction( actionTimeline );
     }
 
     if ( contextMenu.isEmpty() )
@@ -249,58 +146,49 @@ void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
     }
 
     const QAction* const action = contextMenu.exec( event->globalPos() );
-    if ( action == nullptr ) {}
+    if ( action == 0 ) {}
     else if ( action == actionScaleAuto )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setScale( DateTimeGrid::ScaleAuto );
     }
     else if ( action == actionScaleMonth )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setScale( DateTimeGrid::ScaleMonth );
     }
     else if ( action == actionScaleWeek )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setScale( DateTimeGrid::ScaleWeek );
     }
     else if ( action == actionScaleDay )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setScale( DateTimeGrid::ScaleDay );
     }
     else if ( action == actionScaleHour )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setScale( DateTimeGrid::ScaleHour );
     }
     else if ( action == actionZoomIn )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         grid->setDayWidth( grid->dayWidth() * 1.25 );
     }
     else if ( action == actionZoomOut )
     {
-        assert( grid != nullptr );
+        assert( grid != 0 );
         // daywidth *MUST NOT* go below 1.0, it is used as an integer later on
         grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 0.8 ) );
     }
-    else if ( action == actionTimeline )
-    {
-        assert( grid != nullptr );
-        DateTimeTimeLineDialog dlg(grid->timeLine());
-        dlg.exec();
-    }
+
     event->accept();
 }
 
 GraphicsView::Private::Private( GraphicsView* _q )
-  : q( _q ), rowcontroller(nullptr), headerwidget( _q )
-{
-}
-
-GraphicsView::Private::~Private()
+  : q( _q ), rowcontroller(0), headerwidget( _q )
 {
 }
 
@@ -377,31 +265,17 @@ void GraphicsView::Private::slotRowsInserted( const QModelIndex& parent,  int st
     q->updateScene(); // TODO: This might be optimised
 }
 
-void GraphicsView::Private::removeConstraintsRecursive( QAbstractProxyModel *summaryModel, const QModelIndex& index )
-{
-    if ( summaryModel->hasChildren( index ) ) {
-        //qDebug() << "removing constraints from children of"<<index;
-        for ( int row = 0; row < summaryModel->rowCount( index ); ++row ) {
-            const QModelIndex child = summaryModel->index( row, index.column(), index );
-            removeConstraintsRecursive( summaryModel, child );
-        }
-    }
-    //qDebug() << "removing constraints from"<<index;
-    // NOTE: Constraints are mapped to indexes in the summaryModel->sourceModel()
-    const QList<Constraint> clst = scene.constraintModel()->constraintsForIndex( summaryModel->mapToSource( index ) );
-    for ( const Constraint &c : clst ) {
-        scene.constraintModel()->removeConstraint( c );
-    }
-}
-
 void GraphicsView::Private::slotRowsAboutToBeRemoved( const QModelIndex& parent,  int start, int end )
 {
     //qDebug() << "GraphicsView::Private::slotRowsAboutToBeRemoved("<<parent<<start<<end<<")";
-    QAbstractProxyModel *summaryModel = scene.summaryHandlingModel();
     for ( int row = start; row <= end; ++row ) {
-        for ( int col = 0; col < summaryModel->columnCount( parent ); ++col ) {
-            const QModelIndex idx = summaryModel->index( row, col, parent );
-            removeConstraintsRecursive( summaryModel, idx );
+        for ( int col = 0; col < scene.summaryHandlingModel()->columnCount( parent ); ++col ) {
+            //qDebug() << "removing "<<scene.summaryHandlingModel()->index( row, col, parent );
+            const QModelIndex idx = scene.summaryHandlingModel()->index( row, col, parent );
+            QList<Constraint> clst = scene.constraintModel()->constraintsForIndex( idx );
+            Q_FOREACH( Constraint c, clst ) {
+                scene.constraintModel()->removeConstraint( c );
+            }
             scene.removeItem( idx );
         }
     }
@@ -421,46 +295,68 @@ void GraphicsView::Private::slotRowsRemoved( const QModelIndex& parent,  int sta
 void GraphicsView::Private::slotItemClicked( const QModelIndex& idx )
 {
     QModelIndex sidx = idx;//scene.summaryHandlingModel()->mapToSource( idx );
-    Q_EMIT q->clicked( sidx );
-    if (q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, q))
-        Q_EMIT q->activated( sidx );
+    emit q->clicked( sidx );
+    if (q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, q))
+        emit q->activated( sidx );
 }
 
 void GraphicsView::Private::slotItemDoubleClicked( const QModelIndex& idx )
 {
     QModelIndex sidx = idx;//scene.summaryHandlingModel()->mapToSource( idx );
-    Q_EMIT q->qrealClicked( sidx );
-    if (!q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, q))
-        Q_EMIT q->activated( sidx );
+    emit q->qrealClicked( sidx );
+    if (!q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, q))
+        emit q->activated( sidx );
 }
 
 void GraphicsView::Private::slotHeaderContextMenuRequested( const QPoint& pt )
 {
-    Q_EMIT q->headerContextMenuRequested( headerwidget.mapToGlobal( pt ) );
+    emit q->headerContextMenuRequested( headerwidget.mapToGlobal( pt ) );
 }
 
+/*!\class KGantt::GraphicsView kganttgraphicsview.h KGanttGraphicsView
+ * \ingroup KGantt
+ * \brief The GraphicsView class provides a model/view implementation of a gantt chart.
+ *
+ *
+ */
+
+/*! \fn void GraphicsView::activated( const QModelIndex & index ) */
+/*! \fn void GraphicsView::clicked( const QModelIndex & index ); */
+/*! \fn void GraphicsView::qrealClicked( const QModelIndex & index ); */
+/*! \fn void GraphicsView::entered( const QModelIndex & index ); */
+/*! \fn void GraphicsView::pressed( const QModelIndex & index ); */
+/*! \fn void GraphicsView::headerContextMenuRequested( const QPoint& pt )
+ * This signal is emitted when the header has contextMenuPolicy Qt::CustomContextMenu
+ * and the widget wants to show a context menu for the header. Unlike in
+ * QWidget::customContextMenuRequested() signal, \a pt is here in global coordinates.
+ */
+
+/*! Constructor. Creates a new KGantt::GraphicsView with parent
+ * \a parent.
+ */
 GraphicsView::GraphicsView( QWidget* parent )
     : QGraphicsView( parent ), _d( new Private( this ) )
 {
+
 #if defined KDAB_EVAL
   EvalDialog::checkEvalLicense( "KD Gantt" );
 #endif
-    connect( horizontalScrollBar(), SIGNAL(valueChanged(int)),
-             this, SLOT(slotHorizontalScrollValueChanged(int)) );
-    connect( &_d->scene, SIGNAL(gridChanged()),
-             this, SLOT(slotGridChanged()) );
-    connect( &_d->scene, SIGNAL(entered(QModelIndex)),
-             this, SIGNAL(entered(QModelIndex)) );
-    connect( &_d->scene, SIGNAL(pressed(QModelIndex)),
-             this, SIGNAL(pressed(QModelIndex)) );
-    connect( &_d->scene, SIGNAL(clicked(QModelIndex)),
-             this, SLOT(slotItemClicked(QModelIndex)) );
-    connect( &_d->scene, SIGNAL(qrealClicked(QModelIndex)),
-             this, SLOT(slotItemDoubleClicked(QModelIndex)) );
-    connect( &_d->scene, SIGNAL(sceneRectChanged(QRectF)),
-             this, SLOT(updateSceneRect()) );
-    connect( &_d->headerwidget, SIGNAL(customContextMenuRequested(QPoint)),
-             this, SLOT(slotHeaderContextMenuRequested(QPoint)) );
+    connect( horizontalScrollBar(), SIGNAL( valueChanged( int ) ),
+             this, SLOT( slotHorizontalScrollValueChanged( int ) ) );
+    connect( &_d->scene, SIGNAL( gridChanged() ),
+             this, SLOT( slotGridChanged() ) );
+    connect( &_d->scene, SIGNAL( entered( const QModelIndex& ) ),
+             this, SIGNAL( entered( const QModelIndex& ) ) );
+    connect( &_d->scene, SIGNAL( pressed( const QModelIndex& ) ),
+             this, SIGNAL( pressed( const QModelIndex& ) ) );
+    connect( &_d->scene, SIGNAL( clicked( const QModelIndex& ) ),
+             this, SLOT( slotItemClicked( const QModelIndex& ) ) );
+    connect( &_d->scene, SIGNAL( qrealClicked( const QModelIndex& ) ),
+             this, SLOT( slotItemDoubleClicked( const QModelIndex& ) ) );
+    connect( &_d->scene, SIGNAL( sceneRectChanged( const QRectF& ) ),
+             this, SLOT( updateSceneRect() ) );
+    connect( &_d->headerwidget, SIGNAL( customContextMenuRequested( const QPoint& ) ),
+             this, SLOT( slotHeaderContextMenuRequested( const QPoint& ) ) );
     setScene( &_d->scene );
 
     // HACK!
@@ -473,7 +369,7 @@ GraphicsView::GraphicsView( QWidget* parent )
     //setCacheMode( CacheBackground );
 }
 
-
+/*! Destroys this view. */
 GraphicsView::~GraphicsView()
 {
     delete _d;
@@ -481,7 +377,19 @@ GraphicsView::~GraphicsView()
 
 #define d d_func()
 
-
+/*! Sets the model to be displayed in this view to
+ * \a model. The view does not take ownership of the model.
+ *
+ * To make a model work well with GraphicsView it must
+ * have a certain layout. Whether the model is flat or has a
+ * treestrucure is not important, as long as an
+ * AbstractRowController is provided that can navigate the
+ * model.
+ *
+ * GraphicsView operates per row in the model. The data is always
+ * taken from the _last_ item in the row. The ItemRoles used are
+ * Qt::DisplayRole and the roles defined in KGantt::ItemDataRole.
+ */
 void GraphicsView::setModel( QAbstractItemModel* model )
 {
     if ( d->scene.model() ) {
@@ -489,14 +397,13 @@ void GraphicsView::setModel( QAbstractItemModel* model )
     }
 
     d->scene.setModel( model );
-    if (model) {
-        connect( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(updateSceneRect()) );
-    }
+    connect( model, SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
+             this, SLOT( updateSceneRect() ) );
     updateScene();
 }
 
-
+/*! \returns the current model displayed by this view
+ */
 QAbstractItemModel* GraphicsView::model() const
 {
     return d->scene.model();
@@ -510,81 +417,98 @@ void GraphicsView::setSummaryHandlingModel( QAbstractProxyModel* proxyModel )
     /* Connections. We have to rely on the treeview
      * to receive the signals before we do(!)
      */
-    connect( proxyModel, SIGNAL(columnsInserted(QModelIndex,int,int)),
-             this,  SLOT(slotColumnsInserted(QModelIndex,int,int)) );
-    connect( proxyModel, SIGNAL(columnsRemoved(QModelIndex,int,int)),
-             this,  SLOT(slotColumnsRemoved(QModelIndex,int,int)) );
-    connect( proxyModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-             this,  SLOT(slotDataChanged(QModelIndex,QModelIndex)) );
-    connect( proxyModel, SIGNAL(layoutChanged()),
-             this,  SLOT(slotLayoutChanged()) );
-    connect( proxyModel, SIGNAL(modelReset()),
-             this,  SLOT(slotModelReset()) );
-    connect( proxyModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-             this,  SLOT(slotRowsInserted(QModelIndex,int,int)) );
-    connect( proxyModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-             this,  SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
-    connect( proxyModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-             this,  SLOT(slotRowsRemoved(QModelIndex,int,int)) );
+    connect( proxyModel, SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
+             this,  SLOT( slotColumnsInserted( const QModelIndex&,  int, int ) ) );
+    connect( proxyModel, SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
+             this,  SLOT( slotColumnsRemoved( const QModelIndex&,  int, int ) ) );
+    connect( proxyModel, SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
+             this,  SLOT( slotDataChanged( const QModelIndex&, const QModelIndex& ) ) );
+    connect( proxyModel, SIGNAL( layoutChanged() ),
+             this,  SLOT( slotLayoutChanged() ) );
+    connect( proxyModel, SIGNAL( modelReset() ),
+             this,  SLOT( slotModelReset() ) );
+    connect( proxyModel, SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
+             this,  SLOT( slotRowsInserted( const QModelIndex&,  int, int ) ) );
+    connect( proxyModel, SIGNAL( rowsAboutToBeRemoved( const QModelIndex&, int, int ) ),
+             this,  SLOT( slotRowsAboutToBeRemoved( const QModelIndex&,  int, int ) ) );
+    connect( proxyModel, SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
+             this,  SLOT( slotRowsRemoved( const QModelIndex&,  int, int ) ) );
 
     updateScene();
 }
 
-
+/*! Sets the constraintmodel displayed by this view.
+ * \see KGantt::ConstraintModel.
+ */
 void GraphicsView::setConstraintModel( ConstraintModel* cmodel )
 {
     d->scene.setConstraintModel( cmodel );
 }
 
-
+/*! \returns the KGantt::ConstraintModel displayed by this view.
+ */
 ConstraintModel* GraphicsView::constraintModel() const
 {
     return d->scene.constraintModel();
 }
 
-
+/*! \returns the KGantt::SummaryHandlingProxyModel used by this view.
+ */
 QAbstractProxyModel* GraphicsView::summaryHandlingModel() const
 {
     return d->scene.summaryHandlingModel();
 }
 
-
+/*! Sets the root index of the model displayed by this view.
+ * Similar to QAbstractItemView::setRootIndex, default is QModelIndex().
+ */
 void GraphicsView::setRootIndex( const QModelIndex& idx )
 {
     d->scene.setRootIndex( idx );
 }
 
-
+/*! \returns the rootindex for this view.
+ */
 QModelIndex GraphicsView::rootIndex() const
 {
     return d->scene.rootIndex();
 }
 
-
+/*! Sets the QItemSelectionModel used by this view to manage
+ * selections. Similar to QAbstractItemView::setSelectionModel
+ */
 void GraphicsView::setSelectionModel( QItemSelectionModel* model )
 {
     d->scene.setSelectionModel( model );
 }
 
-
+/*! \returns the QItemSelectionModel used by this view
+ */
 QItemSelectionModel* GraphicsView::selectionModel() const
 {
     return d->scene.selectionModel();
 }
 
-
+/*! Sets the KGantt::ItemDelegate used for rendering items on this
+ * view. \see ItemDelegate and QAbstractItemDelegate.
+ */
 void GraphicsView::setItemDelegate( ItemDelegate* delegate )
 {
     d->scene.setItemDelegate( delegate );
 }
 
-
+/*! \returns the ItemDelegate used by this view to render items
+*/
 ItemDelegate* GraphicsView::itemDelegate() const
 {
     return d->scene.itemDelegate();
 }
 
-
+/*! Sets the AbstractRowController used by this view. The
+ * AbstractRowController deals with the height and position
+ * of each row and with which parts of the model are
+ * displayed. \see AbstractRowController
+ */
 void GraphicsView::setRowController( AbstractRowController* rowcontroller )
 {
     d->rowcontroller = rowcontroller;
@@ -592,56 +516,76 @@ void GraphicsView::setRowController( AbstractRowController* rowcontroller )
     updateScene();
 }
 
-
+/*! \returns the AbstractRowController
+ * for this view. \see setRowController
+ */
 AbstractRowController* GraphicsView::rowController() const
 {
     return d->rowcontroller;
 }
 
-
+/*! Sets the AbstractGrid for this view. The grid is an
+ * object that controls how QModelIndexes are mapped
+ * to and from the view and how the background and header
+ * is rendered. \see AbstractGrid and DateTimeGrid.
+ */
 void GraphicsView::setGrid( AbstractGrid* grid )
 {
     d->scene.setGrid( grid );
     d->slotGridChanged();
 }
 
-
+/*! \returns the AbstractGrid used by this view.
+ */
 AbstractGrid* GraphicsView::grid() const
 {
     return d->scene.grid();
 }
 
-
-AbstractGrid* GraphicsView::takeGrid()
-{
-    return d->scene.takeGrid();
-}
-
-
+/*! Sets the view to read-only mode if \a to is true. The default is
+ * read/write if the model permits it.
+ */
 void GraphicsView::setReadOnly( bool ro )
 {
     d->scene.setReadOnly( ro );
 }
 
-
+/*!\returns true iff the view is in read-only mode
+ */
 bool GraphicsView::isReadOnly() const
 {
     return d->scene.isReadOnly();
 }
 
-
+/*! Sets the context menu policy for the header. The default value
+ * Qt::DefaultContextMenu results in a standard context menu on the header
+ * that allows the user to set the scale and zoom.
+ *
+ * Setting this to Qt::CustomContextMenu will cause the signal
+ * headerContextMenuRequested(const QPoint& pt) to be emitted instead.
+ *
+ * \see QWidget::setContextMenuPolicy( Qt::ContextMenuPolicy )
+ */
 void GraphicsView::setHeaderContextMenuPolicy( Qt::ContextMenuPolicy p )
 {
     d->headerwidget.setContextMenuPolicy( p );
 }
 
-
+/*! \returns the context menu policy for the header
+ */
 Qt::ContextMenuPolicy GraphicsView::headerContextMenuPolicy() const
 {
     return d->headerwidget.contextMenuPolicy();
 }
 
-
+/*! Adds a constraint from \a from to \a to. \a modifiers are the
+ * keyboard modifiers pressed by the user when the action is invoked.
+ *
+ * Override this to control how contraints are added. The default
+ * implementation adds a soft constraint unless the Shift key is pressed,
+ * in that case it adds a hard constraint. If a constraint is already
+ * present, it is removed and nothing is added.
+ */
 void GraphicsView::addConstraint( const QModelIndex& from,
                                   const QModelIndex& to,
                                   Qt::KeyboardModifiers modifiers )
@@ -680,7 +624,12 @@ void GraphicsView::resizeEvent( QResizeEvent* ev )
     QGraphicsView::resizeEvent( ev );
 }
 
-
+/*!\returns The QModelIndex for the item located at
+ * position \a pos in the view or an invalid index
+ * if no item was present at that position.
+ *
+ * This is useful for for example contextmenus.
+ */
 QModelIndex GraphicsView::indexAt( const QPoint& pos ) const
 {
     QGraphicsItem* item = itemAt( pos );
@@ -691,19 +640,21 @@ QModelIndex GraphicsView::indexAt( const QPoint& pos ) const
     }
 }
 
-
+/*! \internal */
 void GraphicsView::clearItems()
 {
     d->scene.clearItems();
 }
 
-
+/*! \internal */
 void GraphicsView::updateRow( const QModelIndex& idx )
 {
     d->scene.updateRow( d->scene.summaryHandlingModel()->mapFromSource( idx ) );
 }
 
-
+/*! \internal
+ * Adjusts the bounding rectangle of the scene.
+ */
 void GraphicsView::updateSceneRect()
 {
     /* What to do with this? We need to shrink the view to
@@ -722,12 +673,8 @@ void GraphicsView::updateSceneRect()
 
     /* set scrollbar to keep the same time in view */
     range = horizontalScrollBar()->maximum()-horizontalScrollBar()->minimum();
-    if ( range>0 ) {
-        horizontalScrollBar()->setValue( qRound( hscroll*range ) );
-    } else {
-        // keep header in sync with scene
-        d->headerwidget.scrollTo(r.left());
-    }
+    if ( range>0 ) horizontalScrollBar()->setValue( qRound( hscroll*range ) );
+
     /* We have to update here to adjust for any rows with no
      * information because they are painted with a different
      * background brush
@@ -735,7 +682,9 @@ void GraphicsView::updateSceneRect()
     d->scene.invalidate( QRectF(), QGraphicsScene::BackgroundLayer );
 }
 
-
+/*! \internal
+ * Resets the state of the view.
+ */
 void GraphicsView::updateScene()
 {
     clearItems();
@@ -751,50 +700,74 @@ void GraphicsView::updateScene()
     if ( scene() ) scene()->invalidate( QRectF(), QGraphicsScene::BackgroundLayer );
 }
 
-#if 0
-TODO: For 3.0
-
+/*! \internal */
 GraphicsItem* GraphicsView::createItem( ItemType type ) const
 {
-    Q_UNUSED(type)
-    return new GraphicsItem;
+    return d->scene.createItem( type );
 }
-#endif
-
 
+/*! \internal */
 void GraphicsView::deleteSubtree( const QModelIndex& idx )
 {
     d->scene.deleteSubtree( d->scene.summaryHandlingModel()->mapFromSource( idx ) );
 }
 
-
+/*! Print the Gantt chart using \a printer. If \a drawRowLabels
+ * is true (the default), each row will have it's label printed
+ * on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * This version of print() will print multiple pages.
+ */
 void GraphicsView::print( QPrinter* printer, bool drawRowLabels, bool drawColumnLabels )
 {
     d->scene.print( printer, drawRowLabels, drawColumnLabels );
 }
 
-
+/*! Print part of the Gantt chart from \a start to \a end using \a printer.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * This version of print() will print multiple pages.
+ *
+ * To print a certain range of a chart with a DateTimeGrid, use
+ * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
+ * to figure out the values for \a start and \a end.
+ */
 void GraphicsView::print( QPrinter* printer,  qreal start, qreal end, bool drawRowLabels, bool drawColumnLabels )
 {
     d->scene.print( printer, start, end, drawRowLabels, drawColumnLabels );
 }
 
-
+/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ */
 void GraphicsView::print( QPainter* painter, const QRectF& targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
   d->scene.print(painter, targetRect, drawRowLabels, drawColumnLabels);
 }
 
-
+/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
+ * If \a drawRowLabels is true (the default), each row will have it's
+ * label printed on the left side. If \a drawColumnLabels is true (the
+ * default), each column will have it's label printed at the
+ * top side.
+ *
+ * To print a certain range of a chart with a DateTimeGrid, use
+ * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
+ * to figure out the values for \a start and \a end.
+ */
 void GraphicsView::print( QPainter* painter, qreal start, qreal end,
                           const QRectF& targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
   d->scene.print(painter, start, end, targetRect, drawRowLabels, drawColumnLabels);
 }
 
-void GraphicsView::printDiagram( QPrinter *printer, const PrintingContext &context )
-{
-    d->scene.printDiagram( printer, context );
-}
 
 #include "moc_kganttgraphicsview.cpp"
