@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef KGANTTLEGEND_P_H
@@ -25,7 +25,7 @@
 #include "kganttproxymodel.h"
 
 namespace KGantt {
-    class Q_DECL_HIDDEN Legend::Private {
+    class Legend::Private {
     public:
         ProxyModel proxyModel;
     };
